@@ -36,10 +36,13 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
 
     this->pController = pumpController;
 
-    connect(pController, SIGNAL(openingAuthorizeURL(QUrl)),
-            this, SLOT(showAuthorizationURL(QUrl)));
-    connect(pController, SIGNAL(authorizationStatusChanged(bool)),
-            this, SLOT(showAuthorizationStatus(bool)));
+    connect(pController, &PumpController::openingAuthorizeUrl,
+            this, &AccountDialog::showAuthorizationUrl);
+    connect(pController, &PumpController::authorizationStatusChanged,
+            this, &AccountDialog::showAuthorizationStatus);
+    connect(pController, &PumpController::authorizationSucceeded,
+            this, &AccountDialog::onAuthorizationSucceeded);
+
 
     QFont helpFont;
     helpFont.setPointSize(helpFont.pointSize() - 1);
@@ -83,8 +86,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     QString userIdTooltip = tr("Your address, like username@pumpserver.org");
     userIdLineEdit->setPlaceholderText(userIdTooltip);
     userIdLineEdit->setToolTip("<b></b>" + userIdTooltip); // HTMLized for wordwrap
-    connect(userIdLineEdit, SIGNAL(returnPressed()),
-            this, SLOT(askForToken()));
+    connect(userIdLineEdit, &QLineEdit::returnPressed,
+            this, &AccountDialog::askForToken);
 
     getVerifierButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
                                         tr("Get &Verifier Code"),
@@ -93,8 +96,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                   tr("After clicking this button, a web "
                                      "browser will open, requesting "
                                      "authorization for Dianara"));
-    connect(getVerifierButton, SIGNAL(clicked()),
-            this, SLOT(askForToken()));
+    connect(getVerifierButton, &QAbstractButton::clicked,
+            this, &AccountDialog::askForToken);
 
     this->separatorLine = new QFrame(this);
     separatorLine->setFrameStyle(QFrame::HLine);
@@ -127,26 +130,25 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     verifierLineEdit = new QLineEdit(this);
     verifierLineEdit->setPlaceholderText(verifierTooltip);
     verifierLineEdit->setToolTip("<b></b>" + verifierTooltip);
-    connect(verifierLineEdit, SIGNAL(returnPressed()),
-            this, SLOT(setVerifierCode()));
+    connect(verifierLineEdit, &QLineEdit::textChanged,
+            this, &AccountDialog::onVerifierChanged);
 
 
     authorizeApplicationButton = new QPushButton(QIcon::fromTheme("security-high"),
                                                  tr("&Authorize Application"),
                                                  this);
-    connect(authorizeApplicationButton, SIGNAL(clicked()),
-            this, SLOT(setVerifierCode()));
+    connect(authorizeApplicationButton, &QAbstractButton::clicked,
+            this, &AccountDialog::setVerifierCode);
+    connect(verifierLineEdit, &QLineEdit::returnPressed,
+            authorizeApplicationButton, &QAbstractButton::click);
 
 
 
     // To notify invalid ID or empty verifier code
     // Cleared when typing in any of the two fields
     errorsLabel = new QLabel(this);
-    errorsLabel->setOpenExternalLinks(true);
-    connect(userIdLineEdit, SIGNAL(textChanged(QString)),
-            errorsLabel, SLOT(clear()));
-    connect(verifierLineEdit, SIGNAL(textChanged(QString)),
-            errorsLabel, SLOT(clear()));
+    connect(userIdLineEdit, &QLineEdit::textChanged,
+            errorsLabel, &QLabel::clear);
 
 
     QFont authorizationStatusFont;
@@ -154,6 +156,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     authorizationStatusFont.setBold(true);
 
     authorizationStatusLabel = new QLabel(this);
+    authorizationStatusLabel->setOpenExternalLinks(true);
     authorizationStatusLabel->setFont(authorizationStatusFont);
 
 
@@ -162,15 +165,15 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                  tr("&Save Details"),
                                  this);
     saveButton->setDisabled(true); // Disabled initially
-    connect(saveButton, SIGNAL(clicked()),
-            this, SLOT(saveDetails()));
+    connect(saveButton, &QAbstractButton::clicked,
+            this, &AccountDialog::saveDetails);
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
 
     // Unlock button, visible when the account is already authorized, + info
@@ -189,8 +192,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     this->unlockButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
                                          tr("&Unlock"),
                                          this);
-    connect(unlockButton, SIGNAL(clicked()),
-            this, SLOT(unlockDialog()));
+    connect(unlockButton, &QAbstractButton::clicked,
+            this, &AccountDialog::unlockDialog);
 
 
     //////////////////////////////////////////////////////////////////// Layout
@@ -305,17 +308,16 @@ void AccountDialog::askForToken()
     QSettings settings;
     settings.setValue("isApplicationAuthorized", false); // Until steps are completed
 
-    // Don't fail if there're spaces before or after the ID, they're only human ;)
+    // Don't fail if there are spaces before or after the ID, they're only human ;)
     userIdLineEdit->setText(userIdLineEdit->text().trimmed());
 
     // Match username@server.tld AND check for only 1 @ sign
-    if (QRegExp("\\S+@\\S+\\.\\S+").exactMatch(this->userIdLineEdit->text())
+    if (QRegExp("\\S+@(\\S+\\.\\S+|localhost.*)").exactMatch(userIdLineEdit->text())
      && userIdLineEdit->text().count("@") == 1)
     {
-        // Clear verifier field and re-enable it and the button
+        // Clear verifier field and re-enable it
         this->verifierLineEdit->clear();
         this->verifierLineEdit->setEnabled(true);
-        this->authorizeApplicationButton->setEnabled(true);
 
 
         // Show message about the web browser that will be started
@@ -345,8 +347,8 @@ void AccountDialog::setVerifierCode()
 
     if (!this->verifierLineEdit->text().trimmed().isEmpty())
     {
-        this->pController->authorizeApplication(this->verifierLineEdit->text().trimmed());
-        this->saveButton->setEnabled(true);
+        this->pController->authorizeApplication(this->verifierLineEdit->text()
+                                                                       .trimmed());
     }
     else
     {
@@ -355,6 +357,21 @@ void AccountDialog::setVerifierCode()
 }
 
 
+void AccountDialog::onVerifierChanged(QString newText)
+{
+    this->authorizeApplicationButton->setDisabled(newText.isEmpty());
+
+    this->errorsLabel->clear();
+}
+
+
+
+void AccountDialog::onAuthorizationSucceeded()
+{
+    this->saveButton->setEnabled(true);
+    this->errorsLabel->clear();
+}
+
 
 
 void AccountDialog::showAuthorizationStatus(bool authorized)
@@ -379,16 +396,21 @@ void AccountDialog::showAuthorizationStatus(bool authorized)
  * in case the browser doesn't open automatically
  *
  */
-void AccountDialog::showAuthorizationURL(QUrl url)
+void AccountDialog::showAuthorizationUrl(QUrl url, bool browserLaunched)
 {
     QString message = tr("If the browser doesn't open automatically, "
                          "copy this address manually")
-                      + ":<br><a href=\""
-                      + url.toString()
-                      + "\">"
-                      + url.toString()
-                      + "</a>";
-    this->errorsLabel->setText(message);
+                      + ":<br /><a href=\"" + url.toString() + "\">"
+                      + url.toString() + "</a>";
+
+    this->authorizationStatusLabel->setText(message);
+
+    if (!browserLaunched)
+    {
+        this->errorsLabel->setText("[ "
+                                   + tr("Unable to open web browser!")
+                                   + " ]");
+    }
 }
 
 
@@ -411,15 +433,16 @@ void AccountDialog::saveDetails()
     settings.setValue("userID", newUserId);
     settings.sync();
 
-    emit userIDChanged(newUserId);
-
-
     this->errorsLabel->clear(); // Clear previous error messages, if any
 
+
     // If it's authorized, disable the Save Details button
     if (this->pController->currentlyAuthorized())
     {
         this->saveButton->setDisabled(true);
+
+        // Set wheels in motion only if the auth process is complete
+        emit userIdChanged(newUserId);
     }
 
     this->hide();
