@@ -47,13 +47,17 @@ public:
     void setLockMode(bool locked);
 
 signals:
-    void userIDChanged(QString newUserID);
+    void userIdChanged(QString newUserId);
 
 public slots:
     void askForToken();
     void setVerifierCode();
+
+    void onVerifierChanged(QString newText);
+
+    void onAuthorizationSucceeded();
     void showAuthorizationStatus(bool authorized);
-    void showAuthorizationURL(QUrl url);
+    void showAuthorizationUrl(QUrl url, bool browserLaunched);
 
     void saveDetails();
 
