@@ -58,10 +58,10 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                           PeopleWidget::EmbeddedWidget,
                                           pumpController,
                                           this);
-    connect(peopleWidget, SIGNAL(contactSelected(QIcon,QString,QString)),
-            this, SLOT(copyToSelected(QIcon,QString,QString)));
-    connect(peopleWidget, SIGNAL(addButtonPressed(QIcon,QString,QString)),
-            this, SLOT(copyToSelected(QIcon,QString,QString)));
+    connect(peopleWidget, &PeopleWidget::contactSelected,
+            this, &AudienceSelector::copyToSelected);
+    connect(peopleWidget, &PeopleWidget::addButtonPressed,
+            this, &AudienceSelector::copyToSelected);
 
 
 
@@ -94,8 +94,8 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                                                      QIcon(":/images/button-delete.png")),
                                                     tr("Clear &List"),
                                                     this);
-    connect(clearSelectedListButton, SIGNAL(clicked()),
-            selectedListWidget, SLOT(clear()));
+    connect(clearSelectedListButton, &QAbstractButton::clicked,
+            selectedListWidget, &QListWidget::clear);
 
 
     selectedGroupboxLayout = new QVBoxLayout();
@@ -118,14 +118,14 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
                                                   QIcon(":/images/button-save.png")),
                                  tr("&Done"),
                                  this);
-    connect(doneButton, SIGNAL(clicked()),
-            this, SLOT(setAudience()));
+    connect(doneButton, &QAbstractButton::clicked,
+            this, &AudienceSelector::setAudience);
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(close()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::close);
 
 
     buttonsLayout = new QHBoxLayout();
@@ -146,15 +146,15 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     doneShortcuts << QKeySequence("Ctrl+Return")
                   << QKeySequence("Ctrl+Enter");
     doneAction->setShortcuts(doneShortcuts);
-    connect(doneAction, SIGNAL(triggered()),
-            this, SLOT(setAudience()));
+    connect(doneAction, &QAction::triggered,
+            this, &AudienceSelector::setAudience);
     this->addAction(doneAction);
 
     // ESC is the same as the "Cancel" button
     cancelAction = new QAction(this);
     cancelAction->setShortcut(Qt::Key_Escape);
-    connect(cancelAction, SIGNAL(triggered()),
-            this, SLOT(close()));
+    connect(cancelAction, &QAction::triggered,
+            this, &QWidget::close);
     this->addAction(cancelAction);
 
 
