@@ -53,11 +53,9 @@ AvatarButton::AvatarButton(ASPerson *person,
     {
         this->setGenericAvatarIcon();
 
-        qDebug() << "AvatarButton() Using placeholder, downloading real avatar now";
-
         pController->enqueueAvatarForDownload(person->getAvatar());
-        connect(pController, SIGNAL(avatarStored(QString,QString)),
-                this, SLOT(redrawAvatar(QString,QString)));
+        connect(pController, &PumpController::avatarStored,
+                this, &AvatarButton::redrawAvatar);
     }
 
 
@@ -147,9 +145,10 @@ void AvatarButton::createAvatarMenu()
     }
     this->avatarMenuProfileAction = new QAction(QIcon::fromTheme("internet-web-browser",
                                                                  QIcon(":/images/no-avatar.png")),
-                                                 openProfileString, this);
-    connect(avatarMenuProfileAction, SIGNAL(triggered()),
-            this, SLOT(openAuthorProfileInBrowser()));
+                                                openProfileString,
+                                                this);
+    connect(avatarMenuProfileAction, &QAction::triggered,
+            this, &AvatarButton::openAuthorProfileInBrowser);
     if (authorUrl.isEmpty()) // Disable if there isn't actually an URL
     {
         avatarMenuProfileAction->setDisabled(true);
@@ -165,16 +164,16 @@ void AvatarButton::createAvatarMenu()
                                                 tr("Send message to %1")
                                                 .arg(this->authorName),
                                                 this);
-    connect(avatarMenuMessageAction, SIGNAL(triggered()),
-            this, SLOT(sendMessageToUser()));
+    connect(avatarMenuMessageAction, &QAction::triggered,
+            this, &AvatarButton::sendMessageToUser);
 
 
     this->avatarMenuBrowseAction = new QAction(QIcon::fromTheme("edit-find",
                                                                 QIcon(":/images/menu-find.png")),
                                                tr("Browse messages"),
                                                this);
-    connect(avatarMenuBrowseAction, SIGNAL(triggered()),
-            this, SLOT(browseUserMessages()));
+    connect(avatarMenuBrowseAction, &QAction::triggered,
+            this, &AvatarButton::browseUserMessages);
 
     // Disable 'browse' option if not available (empty or in another server)
     if (!pController->urlIsInOurHost(this->authorOutbox))
@@ -228,10 +227,10 @@ void AvatarButton::setFollowUnfollow()
         this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-remove-user",
                                                                QIcon(":/images/list-remove.png")));
         this->avatarMenuFollowAction->setText(tr("Stop following"));
-        connect(avatarMenuFollowAction, SIGNAL(triggered()),
-                this, SLOT(unfollowUser()));
-        disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
-                   this, SLOT(followUser()));
+        connect(avatarMenuFollowAction, &QAction::triggered,
+                this, &AvatarButton::unfollowUser);
+        disconnect(avatarMenuFollowAction, &QAction::triggered,
+                   this, &AvatarButton::followUser);
         //qDebug() << "post author followed, connecting to UNFOLLOW()" << this->authorId;
     }
     else
@@ -239,10 +238,10 @@ void AvatarButton::setFollowUnfollow()
         this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-add-user",
                                                                QIcon(":/images/list-add.png")));
         this->avatarMenuFollowAction->setText(tr("Follow"));
-        connect(avatarMenuFollowAction, SIGNAL(triggered()),
-                this, SLOT(followUser()));
-        disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
-                   this, SLOT(unfollowUser()));
+        connect(avatarMenuFollowAction, &QAction::triggered,
+                this, &AvatarButton::followUser);
+        disconnect(avatarMenuFollowAction, &QAction::triggered,
+                   this, &AvatarButton::unfollowUser);
         //qDebug() << "post author not followed, connecting to FOLLOW()" << this->authorId;
     }
 }
@@ -266,7 +265,7 @@ void AvatarButton::addActionToMenu(QAction *action)
 
 void AvatarButton::openAuthorProfileInBrowser()
 {
-    QDesktopServices::openUrl(this->authorUrl);
+    MiscHelpers::openUrl(this->authorUrl, this);
 }
 
 
@@ -325,7 +324,7 @@ void AvatarButton::redrawAvatar(QString avatarUrl, QString avatarFilename)
     {
         this->updateAvatarIcon(avatarFilename);
 
-        disconnect(pController, SIGNAL(avatarStored(QString,QString)),
-                   this, SLOT(redrawAvatar(QString,QString)));
+        disconnect(pController, &PumpController::avatarStored,
+                   this, &AvatarButton::redrawAvatar);
     }
 }
