@@ -35,11 +35,11 @@ ColorPicker::ColorPicker(QString description,
     button = new QPushButton(tr("Change..."), this);
     button->setIconSize(QSize(32, 32));
     button->setDisabled(true); // Disabled initially
-    connect(button, SIGNAL(clicked()),
-            this, SLOT(changeColor()));
+    connect(button, &QAbstractButton::clicked,
+            this, &ColorPicker::changeColor);
 
-    connect(checkBox, SIGNAL(toggled(bool)),
-            button, SLOT(setEnabled(bool)));
+    connect(checkBox, &QAbstractButton::toggled,
+            button, &QWidget::setEnabled);
 
     layout = new QHBoxLayout();
     layout->addWidget(descriptionLabel, 10);
