@@ -111,8 +111,8 @@ Comment::Comment(PumpController *pumpController,
     likeLabel->setFont(metadataFont);
     likeLabel->setToolTip("<b></b>"
                           + tr("Like or unlike this comment"));
-    connect(likeLabel, SIGNAL(linkActivated(QString)),
-            this, SLOT(likeComment(QString)));
+    connect(likeLabel, &QLabel::linkActivated,
+            this, &Comment::likeComment);
 
 
 
@@ -125,10 +125,10 @@ Comment::Comment(PumpController *pumpController,
     quoteLabel->setFont(metadataFont);
     quoteLabel->setToolTip("<b></b>"
                            + tr("Reply quoting this comment"));
-    connect(quoteLabel, SIGNAL(linkHovered(QString)),
-            this, SLOT(saveCommentSelectedText()));
-    connect(quoteLabel, SIGNAL(linkActivated(QString)),
-            this, SLOT(quoteComment()));
+    connect(quoteLabel, &QLabel::linkHovered,
+            this, &Comment::saveCommentSelectedText);
+    connect(quoteLabel, &QLabel::linkActivated,
+            this, &Comment::quoteComment);
 
 
     editLabel = new QLabel("<a href=\"edit://\">" + tr("Edit") + "</a>",
@@ -138,8 +138,8 @@ Comment::Comment(PumpController *pumpController,
     editLabel->setFont(metadataFont);
     editLabel->setToolTip("<b></b>"
                           + tr("Modify this comment"));
-    connect(editLabel, SIGNAL(linkActivated(QString)),
-            this, SLOT(editComment()));
+    connect(editLabel, &QLabel::linkActivated,
+            this, &Comment::editComment);
 
 
     deleteLabel = new QLabel("<a href=\"delete://\">"
@@ -150,8 +150,8 @@ Comment::Comment(PumpController *pumpController,
     deleteLabel->setFont(metadataFont);
     deleteLabel->setToolTip("<b></b>"
                             + tr("Erase this comment"));
-    connect(deleteLabel, SIGNAL(linkActivated(QString)),
-            this, SLOT(deleteComment()));
+    connect(deleteLabel, &QLabel::linkActivated,
+            this, &Comment::deleteComment);
 
 
     // The likes count
@@ -173,8 +173,8 @@ Comment::Comment(PumpController *pumpController,
     contentLabel->setTextFormat(Qt::RichText);
     contentLabel->setSizePolicy(sizePolicy);
     contentLabel->setMaximumHeight(4096);
-    connect(contentLabel, SIGNAL(linkHovered(QString)),
-            this, SLOT(showUrlInfo(QString)));
+    connect(contentLabel, &QLabel::linkHovered,
+            this, &Comment::showUrlInfo);
 
 
     // This is used to draw a colored vertical line, as a hint
@@ -403,8 +403,8 @@ void Comment::getPendingImages()
             pController->enqueueImageForDownload(imageUrl);
         }
 
-        connect(pController, SIGNAL(imageStored(QString)),
-                this, SLOT(redrawImages(QString)));
+        connect(pController, &PumpController::imageStored,
+                this, &Comment::redrawImages);
     }
 }
 
@@ -602,11 +602,12 @@ void Comment::redrawImages(QString imageUrl)
         this->pendingImagesList.removeAll(imageUrl);
         if (pendingImagesList.isEmpty()) // If there are no more, disconnect
         {
-            disconnect(pController, SIGNAL(imageStored(QString)),
-                       this, SLOT(redrawImages(QString)));
-
-            setCommentContents();
+            disconnect(pController, &PumpController::imageStored,
+                       this, &Comment::redrawImages);
         }
+
+        // Redraw for every image
+        setCommentContents();
     }
 }
 
@@ -619,7 +620,7 @@ void Comment::redrawImages(QString imageUrl)
 
 
 /*
- * Ensure url info in statusbar is hidden when the mouse leaves the comment
+ * Ensure URL info in statusbar is hidden when the mouse leaves the comment
  *
  */
 void Comment::leaveEvent(QEvent *event)
