@@ -30,14 +30,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
 
-    QFont startConversationFont;
-    startConversationFont.setPointSize(startConversationFont.pointSize() - 2);
+    clickToPostText = tr("Click here or press Control+N to post a note...");
 
-    startConversationLabel = new QLabel(tr("Click here or press Control+N "
-                                           "to post a note..."),
-                                        this);
-    startConversationLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-    startConversationLabel->setFont(startConversationFont);
 
     // A menu to insert some Unicode symbols
     symbolsMenu = new QMenu(tr("Symbols"), this);
@@ -54,8 +48,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     symbolsMenu->addAction(QString::fromUtf8("\342\236\241")); // Arrow to the right
     symbolsMenu->addAction(QString::fromUtf8("\342\231\273")); // Recycling symbol
     symbolsMenu->addAction(QString::fromUtf8("\342\210\236")); // Infinity
-    connect(symbolsMenu, SIGNAL(triggered(QAction*)),
-            this, SLOT(insertSymbol(QAction*)));
+    connect(symbolsMenu, &QMenu::triggered,
+            this, &Composer::insertSymbol);
 
 
     toolsMenu = new QMenu(tr("Formatting"), this);
@@ -147,8 +141,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
                                              this);
 
     pastePlaintextAction->setShortcut(QKeySequence("Ctrl+Shift+V"));
-    connect(pastePlaintextAction, SIGNAL(triggered()),
-            this, SLOT(pasteAsPlaintext()));
+    connect(pastePlaintextAction, &QAction::triggered,
+            this, &Composer::pasteAsPlaintext);
 
     // Add action to this object, in order for the shortcut to work
     // Otherwise, the action isn't available until the context menu is present
@@ -163,8 +157,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     nickCompleter->setCompletionColumn(0);
     nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
     nickCompleter->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
-    connect(nickCompleter, SIGNAL(activated(QModelIndex)),
-            this, SLOT(insertCompletedNick(QModelIndex)));
+    connect(nickCompleter, SIGNAL(activated(QModelIndex)), // Old-style connect()
+            this, SLOT(insertCompletedNick(QModelIndex))); // due to signal overload
 
     popupTableView = new QTableView(this);
     popupTableView->horizontalHeader()->hide();
@@ -183,14 +177,11 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
         this->setToolTip("<b></b>"
                          + tr("Type a message here to post it"));
 
-        mainLayout->addWidget(startConversationLabel, 1, Qt::AlignLeft | Qt::AlignVCenter);
+        this->setPlaceholderText(clickToPostText);
     }
     else                     // or Commenter mode
     {
-        this->setToolTip("<b></b>"
-                         + tr("Type a comment here"));
-
-        startConversationLabel->hide(); // Since it has a parent but it's not used, hide it
+        this->setPlaceholderText(tr("Type a comment here"));
     }
     this->setLayout(mainLayout);
 
@@ -211,7 +202,7 @@ void Composer::erase()
 
     if (this->forPublisher)
     {
-        startConversationLabel->show();
+        this->setPlaceholderText(clickToPostText);
     }
 }
 
@@ -272,20 +263,13 @@ void Composer::requestCompletion(QString partialNick)
 }
 
 
-int Composer::getMessageLabelHeight()
-{
-    // kinda TMP / FIXME
-    return (this->startConversationLabel->font().pointSize() * 4) + 4;
-}
-
-
 /*
  * Hide placeholder message
  *
  */
 void Composer::hideInfoMessage()
 {
-    this->startConversationLabel->hide();
+    this->setPlaceholderText("");
 }
 
 
@@ -326,12 +310,61 @@ void Composer::focusInEvent(QFocusEvent *event)
     qDebug() << "Composer box got focus";
 }
 
+/*
+ * Same signal when having something dropped into the widget
+ *
+ */
+void Composer::dropEvent(QDropEvent *event)
+{
+    qDebug() << "Composer received a drag-and-drop:"
+             << event->mimeData()->text();
+
+    emit focusReceived();
+
+    QList<QUrl> urls = event->mimeData()->urls();
+
+    // Something with a URL was dropped, probably a local file
+    if (!urls.isEmpty())
+    {
+        qDebug() << "** Dropped URLs:" << urls;
+
+        QString fileUrl = urls.first().toLocalFile();
+        if (urls.first().isLocalFile()) // Local, but might be a directory
+        {
+            if (QFileInfo(fileUrl).isFile())
+            {
+                qDebug() << "**** It's a local file:" << fileUrl;
+                if (urls.count() == 1)
+                {
+                    // Clear possible prior error messages
+                    emit errorHappened("");
+                }
+                else
+                {
+                    // Notify user that only one file can be attached
+                    emit errorHappened(tr("You can attach only one file."));
+                }
+
+                emit fileDropped(fileUrl);
+            }
+            else
+            {
+                qDebug() << "**** Dropped a folder!";
+                emit errorHappened(tr("You cannot drop folders here, "
+                                      "only a single file."));
+            }
+
+            return;
+        }
+    }
+
+    QTextEdit::dropEvent(event);
+}
+
 
 
 void Composer::keyPressEvent(QKeyEvent *event)
 {
-    //qDebug() << "Composer::keyPressEvent()";
-
     // Allow cancelling/accepting the autocompletion popup
     if (this->nickCompleter->popup()->isVisible())
     {
@@ -361,24 +394,32 @@ void Composer::keyPressEvent(QKeyEvent *event)
             this->cancelPost();
         }
     }
-    else if (event->key() == Qt::Key_Up && this->textCursor().atStart())
+    else if (event->key() == Qt::Key_Up
+          && event->modifiers() != Qt::ShiftModifier)
     {
-        qDebug() << "KEYPRESS: atStart(); will focus on TITLE field";
-        emit focusTitleRequested();
+        QTextCursor currentCursor = this->textCursor();
+        if (currentCursor.movePosition(QTextCursor::Up)) // true=cursor is able to go up
+        {
+            QTextEdit::keyPressEvent(event);
+        }
+        else
+        {
+            qDebug() << "KEYPRESS UP: Can't go up, will focus on TITLE field";
+            emit focusTitleRequested();
+        }
     }
     else
     {
         QTextEdit::keyPressEvent(event);
 
-        QTextCursor textCursor = this->textCursor();
-        textCursor.select(QTextCursor::WordUnderCursor);
+        QTextCursor currentCursor = this->textCursor();
+        currentCursor.select(QTextCursor::WordUnderCursor);
 
-        //if (event->key() == Qt::Key_At)
-        if (textCursor.document()->characterAt(textCursor.selectionStart() - 1)
+        if (currentCursor.document()->characterAt(currentCursor.selectionStart() - 1)
             == QChar('@'))
         {
             // Show completer
-            this->requestCompletion(textCursor.selectedText());
+            this->requestCompletion(currentCursor.selectedText());
         }
         else
         {
@@ -512,7 +553,8 @@ void Composer::insertFromMimeData(const QMimeData *source)
         qDebug() << "WORD:" << currentWord;
 
         if (currentWord == "http" || currentWord == "https"
-         || currentWord == "ftp"  || currentWord == "sftp")
+         || currentWord == "ftp"  || currentWord == "ftps"
+         || currentWord == "sftp")
         {
             qDebug() << "Text might be a link";
 
@@ -537,6 +579,7 @@ void Composer::insertFromMimeData(const QMimeData *source)
                 if (linkFound.startsWith("http://")
                  || linkFound.startsWith("https://")
                  || linkFound.startsWith("ftp://")
+                 || linkFound.startsWith("ftps://")
                  || linkFound.startsWith("sftp://"))
                 {
                     // Turn current selection into a link to the same as the visible text
@@ -585,7 +628,6 @@ void Composer::makeNormal()
  */
 void Composer::makeBold()
 {
-    //qDebug() << this->textCursor().selectionStart() << " -> "  << this->textCursor().selectionEnd();
     QTextCharFormat charFormat;
     if (this->currentCharFormat().fontWeight() == QFont::Bold)
     {
@@ -662,12 +704,34 @@ void Composer::makeHeader()
 
 void Composer::makeList()
 {
-    QString selectedText = this->textCursor().selectedText();
+    QString selectedText = this->textCursor().selection().toHtml();
+    selectedText = MiscHelpers::cleanupHtml(selectedText);
 
-    if (!selectedText.isEmpty())
+    if (selectedText.isEmpty())
     {
+        this->textCursor().insertList(QTextListFormat::ListDisc);
+    }
+    else
+    {
+        // Capture only the HTML of each line by itself
+        QRegExp pRE("<p .*>(.*)</p>");
+        pRE.setMinimal(true);
+
+        QString listHtml = "<ul>";
+
+        int pos = 0;
+        while ((pos = pRE.indexIn(selectedText, pos)) != -1)
+        {
+            listHtml.append("<li>" + pRE.cap(1) + "</li>");
+            pos += pRE.matchedLength();
+        }
+
+        listHtml.append("</ul><br />");
+
+
         this->textCursor().removeSelectedText();
-        this->insertHtml("<ul><li>" + selectedText + "</li></ul><br>");
+        this->insertHtml(listHtml);
+        this->textCursor().deletePreviousChar(); // Delete undesired extra newline
     }
 
     this->setFocus();
@@ -811,8 +875,8 @@ void Composer::makeLink()
         link = link.trimmed(); // Remove possible spaces before or after
 
         if (link.startsWith("http://") || link.startsWith("https://")
-         || link.startsWith("ftp://")  || link.startsWith("sftp://")
-         || link.startsWith("mailto:"))
+         || link.startsWith("ftp://")  || link.startsWith("ftps://")
+         || link.startsWith("sftp://") || link.startsWith("mailto:"))
         {
             validLink = true;
         }
@@ -833,6 +897,7 @@ void Composer::makeLink()
                                                 "<li>http://</li>"
                                                 "<li>https://</li>"
                                                 "<li>ftp://</li>"
+                                                "<li>ftps://</li>"
                                                 "<li>sftp://</li>"
                                                 "<li>mailto:</li>"
                                                 "</ul>"
