@@ -59,7 +59,6 @@ public:
     void insertLink(QString url, QString title="");
     void requestCompletion(QString partialNick);
 
-    int getMessageLabelHeight();
     void hideInfoMessage();
     QPushButton *getToolsButton();
 
@@ -74,6 +73,10 @@ signals:
 
     void nickInserted(QString id, QString name, QString url);
 
+    void fileDropped(QString fileUrl);
+
+    void errorHappened(QString errorMessage);
+
 
 public slots:
     void makeNormal();
@@ -101,6 +104,7 @@ public slots:
 
 protected:
     virtual void focusInEvent(QFocusEvent *event);
+    virtual void dropEvent(QDropEvent *event);
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void contextMenuEvent(QContextMenuEvent *event);
     virtual void insertFromMimeData(const QMimeData *source);
@@ -109,7 +113,6 @@ protected:
 private:
     QHBoxLayout *mainLayout;
 
-    QLabel *startConversationLabel;
     QPushButton *toolsButton;
     QMenu *toolsMenu;
     QMenu *symbolsMenu;
@@ -121,8 +124,11 @@ private:
     QCompleter *nickCompleter;
     QTableView *popupTableView;
 
+
+    QString clickToPostText;
     bool forPublisher;
 
+
     GlobalObject *globalObj;
 };
 
