@@ -149,8 +149,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesStackedWidget->addWidget(notificationOptionsWidget);
     categoriesStackedWidget->addWidget(systrayOptionsWidget);
 
-    connect(categoriesListWidget, SIGNAL(currentRowChanged(int)),
-            categoriesStackedWidget, SLOT(setCurrentIndex(int)));
+    connect(categoriesListWidget, &QListWidget::currentRowChanged,
+            categoriesStackedWidget, &QStackedWidget::setCurrentIndex);
 
     topLayout = new QHBoxLayout();
     topLayout->addWidget(categoriesListWidget);
@@ -174,14 +174,14 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                                         QIcon(":/images/button-save.png")),
                                        tr("&Save Configuration"),
                                        this);
-    connect(saveConfigButton, SIGNAL(clicked()),
-            this, SLOT(saveConfiguration()));
+    connect(saveConfigButton, &QAbstractButton::clicked,
+            this, &ConfigDialog::saveConfiguration);
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
     this->buttonsLayout = new QHBoxLayout();
     buttonsLayout->setAlignment(Qt::AlignRight);
@@ -192,8 +192,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // ESC to close
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
 
@@ -256,15 +256,15 @@ void ConfigDialog::createGeneralPage(int updateInterval,
                                                          QIcon(":/images/button-configure.png")),
                                         tr("Pro&xy Settings"),
                                         this);
-    connect(proxyConfigButton, SIGNAL(clicked()),
-            proxyDialog, SLOT(show()));
+    connect(proxyConfigButton, &QAbstractButton::clicked,
+            proxyDialog, &QWidget::show);
 
     filterEditorButton = new QPushButton(QIcon::fromTheme("view-filter",
                                                           QIcon(":/images/button-filter.png")),
                                          tr("Set Up F&ilters"),
                                          this);
-    connect(filterEditorButton, SIGNAL(clicked()),
-            this, SIGNAL(filterEditorRequested()));
+    connect(filterEditorButton, &QAbstractButton::clicked,
+            this, &ConfigDialog::filterEditorRequested);
 
 
     QFrame *lineFrame1 = new QFrame(this); // ----------------------------
@@ -435,6 +435,14 @@ void ConfigDialog::createTimelinesPage()
     mfAvatarSizeCombobox = this->newAvatarComboBox();
     mfAvatarSizeCombobox->setCurrentIndex(globalObj->getMfAvatarIndex());
 
+    mfIconTypeCombobox = new QComboBox(this);
+    mfIconTypeCombobox->addItem(tr("No"));
+    mfIconTypeCombobox->addItem(tr("Before avatar"));
+    mfIconTypeCombobox->addItem(tr("Before avatar, subtle"));
+    mfIconTypeCombobox->addItem(tr("After avatar"));
+    mfIconTypeCombobox->addItem(tr("After avatar, subtle"));
+    mfIconTypeCombobox->setCurrentIndex(globalObj->getMfIconType());
+
 
     // TMP/FIXME, use GroupBoxes instead of a separator
     QFrame *lineFrame = new QFrame(this); // -----------------------
@@ -460,6 +468,8 @@ void ConfigDialog::createTimelinesPage()
                                    snippetLimitHlSpinbox);
     timelinesOptionsLayout->addRow(tr("Minor feed avatar sizes"),  // tmp string
                                    mfAvatarSizeCombobox);
+    timelinesOptionsLayout->addRow(tr("Show activity icons"),
+                                   mfIconTypeCombobox);
 
     timelinesOptionsWidget = new QWidget(this);
     timelinesOptionsWidget->setLayout(timelinesOptionsLayout);
@@ -599,6 +609,7 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
                                        tr("Don't show notifications"));
     notificationStyleCombobox->setCurrentIndex(settings->value("showNotifications",
                                                                0).toInt());
+    // Keeping these connects old-style due to overload
     connect(notificationStyleCombobox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(toggleNotificationDetails(int)));
     // Check FD.org notifications availability when selecting an option
@@ -615,11 +626,15 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
                                                           4).toInt()); // 4s default
 
     notificationPersistentCheckbox = new QCheckBox(this);
-    connect(notificationPersistentCheckbox, SIGNAL(toggled(bool)),
-            notificationDurationSpinbox, SLOT(setDisabled(bool)));
+    connect(notificationPersistentCheckbox, &QAbstractButton::toggled,
+            notificationDurationSpinbox, &QWidget::setDisabled);
     notificationPersistentCheckbox->setChecked(settings->value("notificationPersistent",
                                                                false).toBool());
 
+    notificationTaskbarCheckbox = new QCheckBox(this);
+    notificationTaskbarCheckbox->setChecked(globalObj->getNotifyInTaskbar());
+
+
     notifyNewTLCheckbox = new QCheckBox(this);
     notifyNewTLCheckbox->setChecked(settings->value("notifyNewTL",
                                                     false).toBool());
@@ -651,6 +666,8 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
                                       notificationDurationSpinbox);
     notificationOptionsLayout->addRow(tr("Persistent Notifications"),
                                       notificationPersistentCheckbox);
+    notificationOptionsLayout->addRow(tr("Also highlight taskbar entry"),
+                                      notificationTaskbarCheckbox);
 
 
     notificationOptionsLayout->addRow(new QLabel("<br>" // TMP/FIXME: put these options
@@ -688,6 +705,7 @@ void ConfigDialog::createSystrayPage(QSettings *settings)
     systrayIconTypeCombobox->addItem(tr("Custom icon"));
     systrayIconTypeCombobox->setCurrentIndex(settings->value("systrayIconType",
                                                              0).toInt());
+    // connect kept old-style
     connect(systrayIconTypeCombobox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(toggleCustomIconButton(int)));
 
@@ -707,8 +725,8 @@ void ConfigDialog::createSystrayPage(QSettings *settings)
     {
         systrayCustomIconButton->setIcon(QIcon(":/icon/32x32/dianara.png"));
     }
-    connect(systrayCustomIconButton, SIGNAL(clicked()),
-            this, SLOT(pickCustomIconFile()));
+    connect(systrayCustomIconButton, &QAbstractButton::clicked,
+            this, &ConfigDialog::pickCustomIconFile);
 
     // Enable/disable initially based on loaded config
     this->toggleCustomIconButton(systrayIconTypeCombobox->currentIndex());
@@ -885,6 +903,8 @@ void ConfigDialog::saveConfiguration()
                       this->snippetLimitHlSpinbox->value());
     settings.setValue("minorFeedAvatarIndex",
                       this->mfAvatarSizeCombobox->currentIndex());
+    settings.setValue("minorFeedIconType",
+                      this->mfIconTypeCombobox->currentIndex());
 
     this->globalObj->syncTimelinesSettings(this->postsPerPageMainSpinbox->value(),
                                            this->postsPerPageOtherSpinbox->value(),
@@ -894,7 +914,8 @@ void ConfigDialog::saveConfiguration()
                                            this->minorFeedSnippetsCombobox->currentIndex(),
                                            this->snippetLimitSpinbox->value(),
                                            this->snippetLimitHlSpinbox->value(),
-                                           this->mfAvatarSizeCombobox->currentIndex());
+                                           this->mfAvatarSizeCombobox->currentIndex(),
+                                           this->mfIconTypeCombobox->currentIndex());
 
     // Posts
     settings.setValue("postAvatarIndex",
@@ -954,13 +975,16 @@ void ConfigDialog::saveConfiguration()
                       this->notificationDurationSpinbox->value());
     settings.setValue("notificationPersistent",
                       this->notificationPersistentCheckbox->isChecked());
+    settings.setValue("notificationTaskbar",
+                      this->notificationTaskbarCheckbox->isChecked());
     settings.setValue("notifyNewTL",  this->notifyNewTLCheckbox->isChecked());
     settings.setValue("notifyHLTL",   this->notifyHLTLCheckbox->isChecked());
     settings.setValue("notifyNewMW",  this->notifyNewMWCheckbox->isChecked());
     settings.setValue("notifyHLMW",   this->notifyHLMWCheckbox->isChecked());
     settings.setValue("notifyErrors", this->notifyErrorsCheckbox->isChecked());
     this->syncNotifierOptions();
-    this->globalObj->syncNotificationSettings(); // FIXME, still empty
+    this->globalObj->syncNotificationSettings(this->notificationTaskbarCheckbox->isChecked());
+                     // FIXME, most still missing
 
 
     // Tray
@@ -990,7 +1014,8 @@ void ConfigDialog::pickCustomIconFile()
                                                        tr("Select custom icon"),
                                                        systrayIconLastUsedDir,
                                                        tr("Image files")
-                                                       + " (*.png *.jpg *.jpeg *.gif);;"
+                                                       + " (*.png *.jpg *.jpe "
+                                                         "*.jpeg *.gif);;"
                                                        + tr("All files") + " (*)");
 
     if (!systrayCustomIconFN.isEmpty())
@@ -1042,6 +1067,11 @@ void ConfigDialog::toggleNotificationDetails(int currentOption)
         state = false;
     }
 
+    this->notificationDurationSpinbox->setEnabled(state // This one also depends on another option
+                                                  && !notificationPersistentCheckbox->isChecked());
+    this->notificationPersistentCheckbox->setEnabled(state);
+    this->notificationTaskbarCheckbox->setEnabled(state);
+
     this->notifyNewTLCheckbox->setEnabled(state);
     this->notifyHLTLCheckbox->setEnabled(state);
     this->notifyNewMWCheckbox->setEnabled(state);
