@@ -48,8 +48,8 @@ ContactCard::ContactCard(PumpController *pumpController,
     bool validAvatar = this->setAvatar(avatarFilename);
     if (!validAvatar && !contactAvatarUrl.isEmpty())
     {
-        connect(pController, SIGNAL(avatarStored(QString,QString)),
-                this, SLOT(redrawAvatar(QString,QString)));
+        connect(pController, &PumpController::avatarStored,
+                this, &ContactCard::redrawAvatar);
 
         // Download avatar for next time
         pController->enqueueAvatarForDownload(contactAvatarUrl);
@@ -138,7 +138,15 @@ ContactCard::ContactCard(PumpController *pumpController,
     }
     else
     {
-        this->setButtonToFollow();
+        if (asPerson->getId() != pController->currentUserId())
+        {
+            this->setButtonToFollow();
+        }
+        else // Ourselves!
+        {
+            followButton->setText("");
+            followButton->setDisabled(true);
+        }
     }
 
 
@@ -146,8 +154,8 @@ ContactCard::ContactCard(PumpController *pumpController,
                                                      QIcon(":/images/button-download.png")),
                                     tr("Open Profile in Web Browser"),
                                     this);
-    connect(openProfileAction, SIGNAL(triggered()),
-            this, SLOT(openProfileInBrowser()));
+    connect(openProfileAction, &QAction::triggered,
+            this, &ContactCard::openProfileInBrowser);
     if (this->contactUrl.isEmpty()) // Disable if there is no URL
     {
         openProfileAction->setDisabled(true);
@@ -157,15 +165,15 @@ ContactCard::ContactCard(PumpController *pumpController,
                                                      QIcon(":/images/button-edit.png")),
                                     tr("Send Message"),
                                     this);
-    connect(sendMessageAction, SIGNAL(triggered()),
-            this, SLOT(setMessagingModeForContact()));
+    connect(sendMessageAction, &QAction::triggered,
+            this, &ContactCard::setMessagingModeForContact);
 
     browsePostsAction = new QAction(QIcon::fromTheme("edit-find",
                                                      QIcon(":/images/menu-find.png")),
                                     tr("Browse Messages"),
                                     this);
-    connect(browsePostsAction, SIGNAL(triggered()),
-            this, SLOT(browseContactPosts()));
+    connect(browsePostsAction, &QAction::triggered,
+            this, &ContactCard::browseContactPosts);
 
 
 /*
@@ -220,10 +228,10 @@ void ContactCard::setButtonToFollow()
     followButton->setIcon(QIcon::fromTheme("list-add",
                                            QIcon(":/images/list-add.png")));
     followButton->setText(tr("Follow"));
-    connect(followButton, SIGNAL(clicked()),
-            this, SLOT(followContact()));
-    disconnect(followButton, SIGNAL(clicked()),
-               this, SLOT(unfollowContact()));
+    connect(followButton, &QAbstractButton::clicked,
+            this, &ContactCard::followContact);
+    disconnect(followButton, &QAbstractButton::clicked,
+               this, &ContactCard::unfollowContact);
 }
 
 
@@ -232,10 +240,10 @@ void ContactCard::setButtonToUnfollow()
     followButton->setIcon(QIcon::fromTheme("list-remove",
                                            QIcon(":/images/list-remove.png")));
     followButton->setText(tr("Stop Following"));
-    connect(followButton, SIGNAL(clicked()),
-            this, SLOT(unfollowContact()));
-    disconnect(followButton, SIGNAL(clicked()),
-               this, SLOT(followContact()));
+    connect(followButton, &QAbstractButton::clicked,
+            this, &ContactCard::unfollowContact);
+    disconnect(followButton, &QAbstractButton::clicked,
+               this, &ContactCard::followContact);
 }
 
 
@@ -312,7 +320,7 @@ void ContactCard::unfollowContact()
 
 void ContactCard::openProfileInBrowser()
 {
-    QDesktopServices::openUrl(this->contactUrl);
+    MiscHelpers::openUrl(this->contactUrl, this);
 }
 
 void ContactCard::setMessagingModeForContact()
@@ -329,7 +337,7 @@ void ContactCard::browseContactPosts()
     this->globalObj->browseUserMessages(this->contactId,
                                         this->contactName,
                                         QIcon(contactPixmap),
-                                        this->contactOutbox + "/major"); // TMP!
+                                        this->contactOutbox + "/major"); // TMP! FIXME
 }
 
 
@@ -342,8 +350,8 @@ void ContactCard::redrawAvatar(QString avatarUrl, QString avatarFilename)
 {
     if (avatarUrl == this->contactAvatarUrl)
     {
-        disconnect(pController, SIGNAL(avatarStored(QString,QString)),
-                   this, SLOT(redrawAvatar(QString,QString)));
+        disconnect(pController, &PumpController::avatarStored,
+                   this, &ContactCard::redrawAvatar);
 
         this->setAvatar(avatarFilename);
     }
