@@ -29,13 +29,26 @@ ContactList::ContactList(PumpController *pumpController,
     this->globalObj = globalObject;
 
 
+    // Need action defined before its target lineedit, to show localized shortcut
+    goToFilterAction = new QAction(this);
+    goToFilterAction->setShortcut(QKeySequence("Ctrl+F"));
+
     QString filterNote = tr("Type a partial name or ID to find a contact...")
-                         + " (Control+F)";
+                         + " ("
+                         + goToFilterAction->shortcut()
+                                            .toString(QKeySequence::NativeText)
+                         + ")";
+
     this->filterLineEdit = new QLineEdit(this);
     filterLineEdit->setPlaceholderText(filterNote);
     filterLineEdit->setToolTip("<b></b>" + filterNote); // HTMLized for wordwrapping
-    connect(filterLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(filterList(QString)));
+    filterLineEdit->setClearButtonEnabled(true);
+    connect(filterLineEdit, &QLineEdit::textChanged,
+            this, &ContactList::filterList);
+
+    connect(goToFilterAction, &QAction::triggered,
+            this, &ContactList::focusFilterField);
+    this->addAction(goToFilterAction);
 
 
     int iconSize = this->filterLineEdit->sizeHint().height(); // filterLineEdit->font().pixelSize()?
@@ -54,16 +67,10 @@ ContactList::ContactList(PumpController *pumpController,
                                                tr("F&ull List"),
                                                this);
     removeFilterButton->setDisabled(true); // Disabled initially, until a search happens
-    connect(removeFilterButton, SIGNAL(clicked()),
-            filterLineEdit, SLOT(clear()));
+    connect(removeFilterButton, &QAbstractButton::clicked,
+            filterLineEdit, &QLineEdit::clear);
 
 
-    goToFilterAction = new QAction(this);
-    goToFilterAction->setShortcut(QKeySequence("Ctrl+F"));
-    connect(goToFilterAction, SIGNAL(triggered()),
-            filterLineEdit, SLOT(setFocus()));
-    this->addAction(goToFilterAction);
-
 
     // Layout
     this->filterLayout = new QHBoxLayout();
@@ -349,3 +356,21 @@ void ContactList::removeSingleContact(ASPerson *contact)
 
     contact->deleteLater();
 }
+
+
+/*
+ * When pressing Ctrl+F, focus filter field,
+ * or select all text if already focused
+ *
+ */
+void ContactList::focusFilterField()
+{
+    if (this->filterLineEdit->hasFocus())
+    {
+        filterLineEdit->selectAll();
+    }
+    else
+    {
+        filterLineEdit->setFocus();
+    }
+}
