@@ -65,9 +65,7 @@ ContactManager::ContactManager(PumpController *pumpController,
     addressLineEdit->setPlaceholderText(webfingerHelpMessage);
     addressLineEdit->setToolTip("<b></b>"
                                 + webfingerHelpMessage);  // HTML tags to get wordwrap
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     addressLineEdit->setClearButtonEnabled(true);
-#endif
     connect(addressLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(toggleFollowButton(QString)));
     connect(addressLineEdit, SIGNAL(returnPressed()),
@@ -517,17 +515,20 @@ void ContactManager::followContact(QString userId, int httpCode,
         {
             // Really only error 0 would mean unavailable server
             // Any other error code probably means the server is not a Pump server
-            specificError = tr("Following this account at this time "
-                               "will probably not work.");
+            specificError = "<b>&bull;&bull;&bull; "
+                            + tr("Following this account at this time "
+                                 "will probably not work.")
+                            + "</b>";
         }
 
         // Timeout was reached or general connection error
         if (requestTimedOut || httpCode == 0)
         {
-            specificError.append(" "
+            specificError.append(" <b>"
                                  + tr("The %1 server seems unavailable.",
                                       "%1 is a hostname")
-                                   .arg(hostname));
+                                   .arg(hostname)
+                                 + "</b>");
         }
 
         if (serverVersion.isEmpty())
