@@ -38,23 +38,19 @@ EmailChanger::EmailChanger(QString explanation,
     infoLabel->setWordWrap(true);
 
     this->mailLineEdit = new QLineEdit(this);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     mailLineEdit->setClearButtonEnabled(true);
-#endif
-    connect(mailLineEdit, SIGNAL(textEdited(QString)),
-            this, SLOT(validateFields()));
+    connect(mailLineEdit, &QLineEdit::textEdited,
+            this, &EmailChanger::validateFields);
 
     this->mailRepeatLineEdit = new QLineEdit(this);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     mailRepeatLineEdit->setClearButtonEnabled(true);
-#endif
-    connect(mailRepeatLineEdit, SIGNAL(textEdited(QString)),
-            this, SLOT(validateFields()));
+    connect(mailRepeatLineEdit, &QLineEdit::textEdited,
+            this, &EmailChanger::validateFields);
 
     this->passwordLineEdit = new QLineEdit(this);
     passwordLineEdit->setEchoMode(QLineEdit::Password);
-    connect(passwordLineEdit, SIGNAL(textEdited(QString)),
-            this, SLOT(validateFields()));
+    connect(passwordLineEdit, &QLineEdit::textEdited,
+            this, &EmailChanger::validateFields);
 
 
 
@@ -72,23 +68,23 @@ EmailChanger::EmailChanger(QString explanation,
                                          tr("Change"),
                                          this);
     this->changeButton->setDisabled(true); // Initially disabled
-    connect(changeButton, SIGNAL(clicked()),
-            this, SLOT(changeEmail()));
+    connect(changeButton, &QAbstractButton::clicked,
+            this, &EmailChanger::changeEmail);
 
     this->cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                           QIcon(":/images/button-cancel.png")),
                                          tr("&Cancel"),
                                          this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(cancelDialog()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &EmailChanger::cancelDialog);
 
 
 
     // ESC to cancel, too
     cancelAction = new QAction(this);
     cancelAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(cancelAction, SIGNAL(triggered()),
-            this, SLOT(cancelDialog()));
+    connect(cancelAction, &QAction::triggered,
+            this, &EmailChanger::cancelDialog);
     this->addAction(cancelAction);
 
 
