@@ -88,21 +88,19 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
 
     filterWordsLineEdit = new QLineEdit(this);
     filterWordsLineEdit->setPlaceholderText(tr("Keywords..."));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     filterWordsLineEdit->setClearButtonEnabled(true);
-#endif
 
     addFilterButton = new QPushButton(QIcon::fromTheme("list-add",
                                                        QIcon(":/images/list-add.png")),
                                       tr("&Add Filter"),
                                       this);
     addFilterButton->setDisabled(true);
-    connect(addFilterButton, SIGNAL(clicked()),
-            this, SLOT(addFilter()));
-    connect(filterWordsLineEdit, SIGNAL(returnPressed()),
-            this, SLOT(addFilter()));
-    connect(filterWordsLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(onFilterTextChanged(QString)));
+    connect(addFilterButton, &QAbstractButton::clicked,
+            this, &FilterEditor::addFilter);
+    connect(filterWordsLineEdit, &QLineEdit::returnPressed,
+            this, &FilterEditor::addFilter);
+    connect(filterWordsLineEdit, &QLineEdit::textChanged,
+            this, &FilterEditor::onFilterTextChanged);
 
 
 
@@ -116,30 +114,30 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
                                          tr("&Remove Selected Filter"),
                                          this);
     removeFilterButton->setDisabled(true);
-    connect(removeFilterButton, SIGNAL(clicked()),
-            this, SLOT(removeFilter()));
-    connect(currentFiltersListWidget, SIGNAL(currentRowChanged(int)),
-            this, SLOT(onFilterRowChanged(int)));
+    connect(removeFilterButton, &QAbstractButton::clicked,
+            this, &FilterEditor::removeFilter);
+    connect(currentFiltersListWidget, &QListWidget::currentRowChanged,
+            this, &FilterEditor::onFilterRowChanged);
 
 
     saveButton = new QPushButton(QIcon::fromTheme("document-save",
                                                   QIcon(":/images/button-save.png")),
                                  tr("&Save Filters"),
                                  this);
-    connect(saveButton, SIGNAL(clicked()),
-            this, SLOT(saveFilters()));
+    connect(saveButton, &QAbstractButton::clicked,
+            this, &FilterEditor::saveFilters);
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
 
