@@ -62,8 +62,8 @@ FirstRunWizard::FirstRunWizard(AccountDialog *accountDlg,
                                                                     QIcon(":/images/button-password.png")),
                                                    tr("Configure your &account"),
                                                    this);
-    connect(configureAccountButton, SIGNAL(clicked()),
-            accountDialog, SLOT(show()));
+    connect(configureAccountButton, &QAbstractButton::clicked,
+            accountDialog, &QWidget::show);
 
 
 
@@ -82,8 +82,8 @@ FirstRunWizard::FirstRunWizard(AccountDialog *accountDlg,
                                               tr("&Edit your profile"),
                                               this);
     //this->editProfileButton->setDisabled(true); // TMP FIXME
-    connect(editProfileButton, SIGNAL(clicked()),
-            profileEditor, SLOT(show()));
+    connect(editProfileButton, &QAbstractButton::clicked,
+            profileEditor, &QWidget::show);
 
 
 
@@ -107,8 +107,8 @@ FirstRunWizard::FirstRunWizard(AccountDialog *accountDlg,
                                                         QIcon(":/images/menu-find.png")),
                                        tr("Open general program &help window"),
                                        this);
-    connect(helpButton, SIGNAL(clicked()),
-            helpWidget, SLOT(show()));
+    connect(helpButton, &QAbstractButton::clicked,
+            helpWidget, &QWidget::show);
 
 
     // Bottom
@@ -121,8 +121,8 @@ FirstRunWizard::FirstRunWizard(AccountDialog *accountDlg,
                                                          QIcon(":/images/button-close.png")),
                                         tr("&Close"),
                                         this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(close()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::close);
 
 
     // Layout
