@@ -49,8 +49,8 @@ FontPicker::FontPicker(QString description,
                                                     QIcon(":/images/list-add.png")),
                                    tr("Change..."),
                                    this);
-    connect(button, SIGNAL(clicked()),
-            this, SLOT(selectFont()));
+    connect(button, &QAbstractButton::clicked,
+            this, &FontPicker::selectFont);
 
 
     this->layout = new QHBoxLayout();
