@@ -78,7 +78,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                 settings.value("mfSnippetsType",       2).toInt(), // Default: Always
                                 settings.value("snippetCharLimit",     30).toInt(),
                                 settings.value("snippetCharLimitHl",   200).toInt(),
-                                settings.value("minorFeedAvatarIndex", 1).toInt()); // 2nd (32x32) by default
+                                settings.value("minorFeedAvatarIndex", 1).toInt(),  // Default: 2nd (32x32)
+                                settings.value("minorFeedIconType",    0).toInt()); // Default: No
 
 
     ///////////////////////////////////////////////////////////////////// POSTS
@@ -105,7 +106,9 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
 
     ///////////////////////////////////////////////////////////// NOTIFICATIONS
-    this->syncNotificationSettings(); // Dummy, TODO
+    this->syncNotificationSettings(settings.value("notificationTaskbar",
+                                                  true).toBool());
+                                          // TODO: load the other nofification options
 
 
     ////////////////////////////////////////////////////////////////////// TRAY
@@ -219,7 +222,7 @@ void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
                                          bool showDeleted, bool hideDuplicates,
                                          bool jumpToNew, int minorFeedSnippets,
                                          int snippetsChars, int snippetsCharsHl,
-                                         int mfAvatarIdx)
+                                         int mfAvatarIdx, int mfVerbIconType)
 {
     this->postsPerPageMain = pppMain;
     this->postsPerPageOther = pppOther;
@@ -234,6 +237,8 @@ void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
     this->mfAvatarIndex = mfAvatarIdx;
     this->mfAvatarSize = this->getAvatarSizeForIndex(mfAvatarIdx);
 
+    this->mfIconType = mfVerbIconType;
+
     // TODO: more...
 }
 
@@ -287,6 +292,11 @@ QSize GlobalObject::getMfAvatarSize()
     return this->mfAvatarSize;
 }
 
+int GlobalObject::getMfIconType()
+{
+    return this->mfIconType;
+}
+
 
 
 // Post options
@@ -413,9 +423,16 @@ bool GlobalObject::getSilentLikes()
 
 
 // Notification options
-void GlobalObject::syncNotificationSettings()
+void GlobalObject::syncNotificationSettings(bool notifyTaskbar)
 {
-    // TODO, still handled elsewhere
+    this->notifyInTaskbar = notifyTaskbar;
+
+    // TODO, most still handled elsewhere
+}
+
+bool GlobalObject::getNotifyInTaskbar()
+{
+    return this->notifyInTaskbar;
 }
 
 
