@@ -66,7 +66,7 @@ public:
                                bool showDeleted, bool hideDuplicates,
                                bool jumpToNew, int minorFeedSnippets,
                                int snippetsChars, int snippetsCharsHl,
-                               int mfAvatarIdx);
+                               int mfAvatarIdx, int mfVerbIconType);
     int getPostsPerPageMain();
     int getPostsPerPageOther();
     bool getShowDeleted();
@@ -77,6 +77,7 @@ public:
     int getSnippetsCharLimitHl();
     int getMfAvatarIndex();
     QSize getMfAvatarSize();
+    int getMfIconType();
 
 
 
@@ -114,7 +115,8 @@ public:
 
 
     // Notification options
-    void syncNotificationSettings();
+    void syncNotificationSettings(bool notifyTaskbar);
+    bool getNotifyInTaskbar();
 
 
     // Tray options
@@ -200,6 +202,7 @@ private:
     int snippetsCharLimitHl;
     int mfAvatarIndex;
     QSize mfAvatarSize;
+    int mfIconType;
 
 
     // Post options
@@ -228,6 +231,7 @@ private:
 
 
     // Notification options
+    bool notifyInTaskbar;
 
 
     // Tray options
