@@ -43,8 +43,8 @@ GroupsManager::GroupsManager(PumpController *pumpController,
     this->createGroupButton = new QPushButton(QIcon::fromTheme("user-group-new"),
                                               "&CREATE GROUP",
                                               this);
-    connect(createGroupButton, SIGNAL(clicked()),
-            this, SLOT(createGroup()));
+    connect(createGroupButton, &QAbstractButton::clicked,
+            this, &GroupsManager::createGroup);
 
     this->joinLeaveGroupLineEdit = new QLineEdit(this);
     joinLeaveGroupLineEdit->setPlaceholderText("ID of the group you wish to "
@@ -53,21 +53,21 @@ GroupsManager::GroupsManager(PumpController *pumpController,
     this->joinGroupButton = new QPushButton(QIcon::fromTheme("list-add-user"),
                                             "&JOIN!",
                                             this);
-    connect(joinGroupButton, SIGNAL(clicked()),
-            this, SLOT(joinGroup()));
+    connect(joinGroupButton, &QAbstractButton::clicked,
+            this, &GroupsManager::joinGroup);
 
     this->leaveGroupButton = new QPushButton(QIcon::fromTheme("list-remove-user"),
                                              "&LEAVE",
                                              this);
-    connect(leaveGroupButton, SIGNAL(clicked()),
-            this, SLOT(leaveGroup()));
+    connect(leaveGroupButton, &QAbstractButton::clicked,
+            this, &GroupsManager::leaveGroup);
 
 
 
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
     // Layout
