@@ -36,8 +36,8 @@ HClabel::HClabel(QString initialText,
 
     this->toggleTimer = new QTimer(this);
     toggleTimer->setSingleShot(true);
-    connect(toggleTimer, SIGNAL(timeout()),
-            this, SLOT(toggleContent()));
+    connect(toggleTimer, &QTimer::timeout,
+            this, &HClabel::toggleContent);
 
     qDebug() << "HClabel created";
 }
