@@ -315,16 +315,16 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
                                                    QIcon(":/images/button-close.png")),
                                   tr("&Close"),
                                   this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
     QList<QKeySequence> closeShortcuts;
     closeShortcuts << QKeySequence(Qt::Key_Escape);
     closeShortcuts << QKeySequence(Qt::Key_F1);
     closeAction = new QAction(this);
     closeAction->setShortcuts(closeShortcuts);
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
     mainLayout = new QVBoxLayout();
