@@ -34,7 +34,7 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     this->setWindowIcon(QIcon::fromTheme("folder-image",
                                          QIcon(":/images/attached-image.png")));
     this->setWindowFlags(Qt::Window);
-    this->setMinimumSize(640, 320);
+    this->setMinimumSize(420, 420);
 
     this->imageUrl = url;
 
@@ -43,12 +43,12 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
 
     zoomLevel = 1.000;
     rotationAngle = 0.000;
-    fitToWindow = true;
+    fitToWindow = false;
 
     loadingLabel = new QLabel(this);
     loadingLabel->setAlignment(Qt::AlignCenter);
 
-    graphicsPixmapItem = new QGraphicsPixmapItem(nullptr); // FIXME: ensure deletion
+    graphicsPixmapItem = new QGraphicsPixmapItem(nullptr);
     graphicsScene = new QGraphicsScene(this);
 
     // This label needs to NOT have a parent, to work properly inside the QGraphicsScene
@@ -57,6 +57,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
 
     ivGraphicsView = new IvGraphicsView(graphicsScene, this);
     ivGraphicsView->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
+    connect(ivGraphicsView, &IvGraphicsView::zoomableModeRequested,
+            this, &ImageViewer::setFullMode);
 
 
     // Buttons
@@ -65,8 +67,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                       tr("&Save As..."),
                                       this);
     saveImageButton->setDisabled(true);
-    connect(saveImageButton, SIGNAL(clicked()),
-            this, SLOT(saveImage()));
+    connect(saveImageButton, &QAbstractButton::clicked,
+            this, &ImageViewer::saveImage);
 
 
     if (imageIsAnimated)
@@ -79,8 +81,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                            "Restart animation"),
                                         this);
         restartButton->setDisabled(true);
-        connect(restartButton, SIGNAL(clicked()),
-                this, SLOT(restartAnimation()));
+        connect(restartButton, &QAbstractButton::clicked,
+                this, &ImageViewer::restartAnimation);
     }
 
 
@@ -88,14 +90,22 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                 tr("Fit",
                                    "As in: fit image to window"),
                                 this);
-    connect(fitButton, SIGNAL(clicked()),
-            this, SLOT(zoomToFit()));
+    connect(fitButton, &QAbstractButton::clicked,
+            this, &ImageViewer::zoomToFit);
+
+
+    zoomLabel = new QLabel("000%", this);
+    zoomLabel->setAlignment(Qt::AlignCenter);
+    zoomLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
+    zoomLabel->setMinimumWidth(zoomLabel->sizeHint().width());
+    zoomLabel->clear();
+
 
     fullButton = new QPushButton(QIcon::fromTheme("zoom-original"),
                                  "100%",
                                  this);
-    connect(fullButton, SIGNAL(clicked()),
-            this, SLOT(zoomToFit()));
+    connect(fullButton, &QAbstractButton::clicked,
+            this, &ImageViewer::zoomToFull);
 
 
     zoomInButton = new QPushButton(QIcon::fromTheme("zoom-in"),
@@ -103,10 +113,10 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                    this);
     zoomInButton->setShortcut(QKeySequence(Qt::Key_Plus));
     zoomInButton->setDisabled(true);
-    connect(zoomInButton, SIGNAL(clicked()),
-            this, SLOT(zoomIn()));
-    connect(ivGraphicsView, SIGNAL(zoomInRequested()),
-            zoomInButton, SLOT(click()));
+    connect(zoomInButton, &QAbstractButton::clicked,
+            this, &ImageViewer::zoomIn);
+    connect(ivGraphicsView, &IvGraphicsView::zoomInRequested,
+            zoomInButton, &QAbstractButton::click);
 
 
     zoomOutButton = new QPushButton(QIcon::fromTheme("zoom-out"),
@@ -114,10 +124,10 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                     this);
     zoomOutButton->setShortcut(QKeySequence(Qt::Key_Minus));
     zoomOutButton->setDisabled(true);
-    connect(zoomOutButton, SIGNAL(clicked()),
-            this, SLOT(zoomOut()));
-    connect(ivGraphicsView, SIGNAL(zoomOutRequested()),
-            zoomOutButton, SLOT(click()));
+    connect(zoomOutButton, &QAbstractButton::clicked,
+            this, &ImageViewer::zoomOut);
+    connect(ivGraphicsView, &IvGraphicsView::zoomOutRequested,
+            zoomOutButton, &QAbstractButton::click);
 
 
     rotateLeftButton = new QPushButton(QIcon::fromTheme("object-rotate-left",
@@ -126,8 +136,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     rotateLeftButton->setToolTip(tr("Rotate image to the left",
                                     "RTL: This actually means LEFT, anticlockwise"));
     rotateLeftButton->setDisabled(true);
-    connect(rotateLeftButton, SIGNAL(clicked(bool)),
-            this, SLOT(rotateLeft()));
+    connect(rotateLeftButton, &QAbstractButton::clicked,
+            this, &ImageViewer::rotateLeft);
 
     rotateRightButton = new QPushButton(QIcon::fromTheme("object-rotate-right",
                                                          QIcon(":/images/button-rotright.png")),
@@ -135,11 +145,11 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     rotateRightButton->setToolTip(tr("Rotate image to the right",
                                      "RTL: This actually means RIGHT, clockwise"));
     rotateRightButton->setDisabled(true);
-    connect(rotateRightButton, SIGNAL(clicked(bool)),
-            this, SLOT(rotateRight()));
+    connect(rotateRightButton, &QAbstractButton::clicked,
+            this, &ImageViewer::rotateRight);
 
 
-    infoLabel = new QLabel(this);
+    infoLabel = new QLabel("~    ~    ~    ~    ~    ~    ~", this);
     infoLabel->setAlignment(Qt::AlignCenter);
 
 
@@ -147,10 +157,11 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
                                                    QIcon(":/images/button-close.png")),
                                   tr("&Close"),
                                   this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(close()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::close);
 
 
+    // This needs to be created after the buttons, since it uses info from them
     this->createContextMenu();
 
 
@@ -159,6 +170,7 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     fitFullLayout->setContentsMargins(0, 0, 0, 0);
     fitFullLayout->setSpacing(0);
     fitFullLayout->addWidget(fitButton);
+    fitFullLayout->addWidget(zoomLabel);
     fitFullLayout->addWidget(fullButton);
 
     buttonsLayout = new QHBoxLayout();
@@ -184,9 +196,13 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
 
     this->updateButtons();
 
-    // Ensure these are disabled until image is actually loaded
-    this->fitButton->setDisabled(true);
-    this->fullButton->setDisabled(true);
+    // For big enough images, "Fit mode" will be automatically enabled by timer
+    this->autoFitTimer = new QTimer(this);
+    autoFitTimer->setSingleShot(true);
+    autoFitTimer->setInterval(50);
+    connect(autoFitTimer, &QTimer::timeout,
+            this, &ImageViewer::checkAutoFit);
+
 
     this->loadImage(this->imageUrl, imageSize);
 
@@ -195,6 +211,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     QDesktopWidget desktopWidget;
     int desktopWidth = desktopWidget.availableGeometry().width();
     int desktopHeight = desktopWidget.availableGeometry().height();
+    qDebug() << "Available desktop area: "
+             << desktopWidth << "x" << desktopHeight;
 
     int imageWidth = imageSize.width();
     int imageHeight = imageSize.height();
@@ -205,17 +223,49 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
         imageHeight = originalPixmap.height();
     }
 
-    int windowWidth = qMin(imageWidth + 100, // Some margin for the window itself
-                           desktopWidth);
-    int windowHeight = qMin(imageHeight + 100,
+    int windowWidth = qMin(imageWidth + 200, // Some margin for the window itself,
+                           desktopWidth);    // and extra width for the buttons
+    int windowHeight = qMin(imageHeight + 160,
                             desktopHeight);
 
-    // Resize window only if image is big enough, otherwise leave resizing up to the layout
-    if (imageWidth > (desktopWidth / 3)      // Kinda TMP...
-     || imageHeight > (desktopHeight / 3))
+
+    // Calculate optimal minimum width for the window,
+    // in order for all the buttons to be readable
+    int desiredWidth = saveImageButton->sizeHint().width()
+                     + fitButton->sizeHint().width()
+                     + zoomLabel->sizeHint().width()
+                     + fullButton->sizeHint().width()
+                     + zoomInButton->sizeHint().width()
+                     + zoomOutButton->sizeHint().width()
+                     + rotateLeftButton->sizeHint().width()
+                     + rotateRightButton->sizeHint().width()
+                     + infoLabel->sizeHint().width()
+                     + closeButton->sizeHint().width()
+                     + (buttonsLayout->spacing() * 12); // With a few extra spacings
+    if (imageIsAnimated)
     {
-        this->resize(windowWidth, windowHeight);
+        desiredWidth += restartButton->sizeHint().width()
+                        + buttonsLayout->spacing();
     }
+    qDebug() << "Sum of button sizeHints, minimal optimal width:"
+             << desiredWidth;
+
+    if (desiredWidth > windowWidth && desiredWidth < desktopWidth)
+    {
+        windowWidth = desiredWidth;
+    }
+
+    // Resize window to our desired size, bigger than the image if the image is small
+    this->resize(windowWidth, windowHeight);
+
+
+    // Ensure these are disabled until image is actually loaded
+    this->fitButton->setDisabled(true);
+    this->fullButton->setDisabled(true);
+    this->zoomInButton->setDisabled(true);
+    this->zoomOutButton->setDisabled(true);
+
+    this->autoFitTimer->start();
 
     qDebug() << "ImageViewer created";
 }
@@ -224,59 +274,69 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
 ImageViewer::~ImageViewer()
 {
     delete movieLabel; // Since it needed to have no parent
-    delete this->graphicsPixmapItem; // Needed? FIXME
+    delete graphicsPixmapItem;
     qDebug() << "ImageViewer destroyed";
 }
 
 
 /*
  * Context menu entries are connected to the corresponding buttons simulated
- * click, to provide visual feedback
+ * click, to provide visual feedback.
+ *
+ * Icons will be taken from them where possible.
  *
  */
 void ImageViewer::createContextMenu()
 {
-    this->saveAction = new QAction(QIcon::fromTheme("document-save-as",
-                                                    QIcon(":/images/button-save.png")),
+    this->saveAction = new QAction(saveImageButton->icon(),
                                    tr("Save Image..."),
                                    this);
     saveAction->setShortcut(QKeySequence("Ctrl+S"));
     saveAction->setDisabled(true);
-    connect(saveAction, SIGNAL(triggered()),
-            saveImageButton, SLOT(animateClick()));
+    connect(saveAction, &QAction::triggered,
+            saveImageButton, &QAbstractButton::animateClick);
 
-    // Name of this action comes from the rotate-left button, already created
-    this->rotateLeftAction = new QAction(QIcon::fromTheme("object-rotate-left",
-                                                          QIcon(":/images/button-rotleft.png")),
+    // This one gets icon and name from fit button initially,
+    // and from 100% button when toggled
+    this->toggleFitFullAction = new QAction(fitButton->icon(),
+                                            fitButton->text(),
+                                            this);
+    toggleFitFullAction->setShortcut(QKeySequence(Qt::Key_F));
+    connect(toggleFitFullAction, &QAction::triggered,
+            this, &ImageViewer::onFitFullToggled);
+
+
+    // Name of this one comes from the rotate-left button's tooltip, already created
+    this->rotateLeftAction = new QAction(rotateLeftButton->icon(),
                                          rotateLeftButton->toolTip(),
                                          this);
     rotateLeftAction->setShortcut(QKeySequence("Ctrl+Left"));
     rotateLeftAction->setDisabled(true);
-    connect(rotateLeftAction, SIGNAL(triggered()),
-            rotateLeftButton, SLOT(animateClick()));
+    connect(rotateLeftAction, &QAction::triggered,
+            rotateLeftButton, &QAbstractButton::animateClick);
 
     // Name of this action comes from the rotate-right button, already created
-    this->rotateRightAction = new QAction(QIcon::fromTheme("object-rotate-right",
-                                                          QIcon(":/images/button-rotright.png")),
-                                         rotateRightButton->toolTip(),
-                                         this);
+    this->rotateRightAction = new QAction(rotateRightButton->icon(),
+                                          rotateRightButton->toolTip(),
+                                          this);
     rotateRightAction->setShortcut(QKeySequence("Ctrl+Right"));
     rotateRightAction->setDisabled(true);
-    connect(rotateRightAction, SIGNAL(triggered()),
-            rotateRightButton, SLOT(animateClick()));
+    connect(rotateRightAction, &QAction::triggered,
+            rotateRightButton, &QAbstractButton::animateClick);
 
 
-    this->closeAction = new QAction(QIcon::fromTheme("window-close",
-                                                     QIcon(":/images/button-close.png")),
+    this->closeAction = new QAction(closeButton->icon(),
                                     tr("Close Viewer"),
                                     this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            closeButton, SLOT(animateClick()));
+    connect(closeAction, &QAction::triggered,
+            closeButton, &QAbstractButton::animateClick);
 
 
     this->contextMenu = new QMenu("imageViewerMenu", this);
     contextMenu->addAction(saveAction);
+    contextMenu->addSeparator();
+    contextMenu->addAction(toggleFitFullAction);
     contextMenu->addAction(rotateLeftAction);
     contextMenu->addAction(rotateRightAction);
     contextMenu->addSeparator();
@@ -284,6 +344,7 @@ void ImageViewer::createContextMenu()
 
     // Make the shortcuts work
     this->addAction(saveAction);
+    this->addAction(toggleFitFullAction);
     this->addAction(rotateLeftAction);
     this->addAction(rotateRightAction);
     this->addAction(closeAction);
@@ -351,6 +412,8 @@ void ImageViewer::loadImage(QString url, QSize expectedSize)
 
         this->rotateLeftAction->setEnabled(true);
         this->rotateRightAction->setEnabled(true);
+
+        this->autoFitTimer->start();
     }
 }
 
@@ -358,29 +421,38 @@ void ImageViewer::loadImage(QString url, QSize expectedSize)
 
 void ImageViewer::drawImage()
 {
-    toggleZoomButtons();
-
     ivGraphicsView->resetTransform(); // Reset and re-scaled+re-rotated every time
+    //// FIXME: This reset causes issues when zooming towards a corner,
+    ///         and then zooming towards the opposite corner
+
     ivGraphicsView->rotate(this->rotationAngle);
 
     if (fitToWindow)
     {
-        ivGraphicsView->fitInView(graphicsPixmapItem, Qt::KeepAspectRatio);
+        zoomLevel = ivGraphicsView->getScaleToFit(originalPixmap.width(),
+                                                  originalPixmap.height(),
+                                                  rotationAngle);
     }
     else
     {
-        ivGraphicsView->scale(zoomLevel, zoomLevel);
-        fullButton->setText(QString("%1%").arg(zoomLevel * 100));
+        toggleZoomButtons();
     }
 
+
+    ivGraphicsView->scale(zoomLevel, zoomLevel);
+
+    zoomLabel->setText(QString("%1%").arg(zoomLevel * 100, 3, 'f', 0));
+
     this->updateButtons();
 }
 
 
 void ImageViewer::toggleZoomButtons()
 {
-    this->zoomInButton->setDisabled(this->zoomLevel >= 4.0);
-    this->zoomOutButton->setDisabled(this->zoomLevel <= 0.1);
+    this->zoomInButton->setDisabled(this->zoomLevel >= 5.00);
+    this->zoomOutButton->setDisabled(this->zoomLevel <= 0.05);
+
+    this->fullButton->setDisabled(this->zoomLevel == 1.0);
 }
 
 
@@ -391,22 +463,25 @@ void ImageViewer::updateButtons()
         this->fitButton->setDisabled(true);
         this->fullButton->setEnabled(true);
 
-        fullButton->setShortcut(QKeySequence(Qt::Key_F));
-
         this->zoomInButton->setVisible(false);
         this->zoomInButton->setEnabled(false);
         this->zoomOutButton->setVisible(false);
         this->zoomOutButton->setEnabled(false);
+
+        this->toggleFitFullAction->setIcon(fullButton->icon());
+        this->toggleFitFullAction->setText(fullButton->text());
     }
     else
     {
         this->fullButton->setDisabled(true);
         this->fitButton->setEnabled(true);
 
-        fitButton->setShortcut(QKeySequence(Qt::Key_F));
-
         this->zoomInButton->setVisible(true);
         this->zoomOutButton->setVisible(true);
+
+        this->toggleFitFullAction->setIcon(fitButton->icon());
+        this->toggleFitFullAction->setText(fitButton->text());
+
         this->toggleZoomButtons();
     }
 }
@@ -481,11 +556,27 @@ void ImageViewer::restartAnimation()
 
 void ImageViewer::zoomToFit()
 {
-    this->fitToWindow = !fitToWindow;
+    this->fitToWindow = true;
+    this->drawImage();
+}
+
+
+void ImageViewer::zoomToFull()
+{
+    this->fitToWindow = false;
     this->zoomLevel = 1.000; // Reset
 
-    this->fullButton->setText("100%");
+    this->drawImage();
+}
 
+
+/*
+ * To be called on wheelEvent, instead of zoomToFit, not resetting zoom level
+ *
+ */
+void ImageViewer::setFullMode()
+{
+    this->fitToWindow = false;
     this->drawImage();
 }
 
@@ -494,12 +585,19 @@ void ImageViewer::zoomIn()
 {
     this->fitToWindow = false;
 
-    if (zoomLevel < 4.0)
+    if (zoomLevel < 5.0)
     {
-        zoomLevel += 0.1;
-        if (zoomLevel > 4.0)
+        if (zoomLevel >= 1.0)
         {
-            zoomLevel = 4.000;
+            zoomLevel += 0.1;
+            if (zoomLevel > 5.0)
+            {
+                zoomLevel = 5.0;
+            }
+        }
+        else
+        {
+            zoomLevel += 0.05;
         }
 
         this->drawImage();
@@ -512,12 +610,19 @@ void ImageViewer::zoomOut()
 {
     this->fitToWindow = false;
 
-    if (zoomLevel > 0.10)
+    if (zoomLevel > 0.05)
     {
-        zoomLevel -= 0.1;
-        if (zoomLevel < 0.1)
+        if (zoomLevel >= 1.1)
         {
-            zoomLevel = 0.100;
+            zoomLevel -= 0.1;
+        }
+        else
+        {
+            zoomLevel -=0.05;
+            if (zoomLevel < 0.05)
+            {
+                zoomLevel = 0.05;
+            }
         }
 
         this->drawImage();
@@ -525,10 +630,33 @@ void ImageViewer::zoomOut()
 }
 
 
+void ImageViewer::checkAutoFit()
+{
+    if (this->originalPixmap.isNull())
+    {
+        // Avoid messing with the buttons until the image is loaded
+        return;
+    }
+
+
+    zoomToFit();
+
+    if (originalPixmap.width() < ivGraphicsView->viewport()->width()
+     && originalPixmap.height() < ivGraphicsView->viewport()->height())
+    {
+        zoomToFull();
+    }
+}
+
+
 
 void ImageViewer::rotateLeft()
 {
     this->rotationAngle -= 90.0;
+    if (rotationAngle == -360.0)
+    {
+        rotationAngle = 0.0;
+    }
 
     this->drawImage();
 }
@@ -537,11 +665,28 @@ void ImageViewer::rotateLeft()
 void ImageViewer::rotateRight()
 {
     this->rotationAngle += 90.0;
+    if (rotationAngle == 360.0)
+    {
+        rotationAngle = 0.0;
+    }
 
     this->drawImage();
 }
 
 
+void ImageViewer::onFitFullToggled()
+{
+    if (fitToWindow)
+    {
+        this->fullButton->animateClick();
+    }
+    else
+    {
+        this->fitButton->animateClick();
+    }
+}
+
+
 
 /****************************************************************************/
 /********************************** PROTECTED *******************************/
