@@ -38,6 +38,7 @@
 #include <QScrollArea>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsProxyWidget>
+#include <QTimer>
 
 #include <QDebug>
 
@@ -73,12 +74,17 @@ public slots:
     void restartAnimation();
 
     void zoomToFit();
+    void zoomToFull();
+    void setFullMode();
     void zoomIn();
     void zoomOut();
+    void checkAutoFit();
 
     void rotateLeft();
     void rotateRight();
 
+    void onFitFullToggled();
+
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
@@ -102,6 +108,7 @@ private:
 
     QHBoxLayout *fitFullLayout;
     QPushButton *fitButton;
+    QLabel *zoomLabel;
     QPushButton *fullButton;
     QPushButton *zoomInButton;
     QPushButton *zoomOutButton;
@@ -114,10 +121,14 @@ private:
 
     QMenu *contextMenu;
     QAction *saveAction;
+    QAction *toggleFitFullAction;
     QAction *rotateLeftAction;
     QAction *rotateRightAction;
     QAction *closeAction;
 
+    QTimer *autoFitTimer;
+
+
     QString imageUrl;
 
     QPixmap originalPixmap;
