@@ -15,10 +15,15 @@ public:
     explicit IvGraphicsView(QGraphicsScene *scene, QWidget *parent = 0);
     ~IvGraphicsView();
 
+    double getScaleToFit(int width, int height, int angle);
+
 signals:
     void zoomInRequested();
     void zoomOutRequested();
 
+    void zoomableModeRequested();
+
+
 public slots:
 
 protected:
