@@ -78,9 +78,7 @@ ListsManager::ListsManager(PumpController *pumpController,
 
     this->newListNameLineEdit = new QLineEdit(this);
     newListNameLineEdit->setPlaceholderText(tr("Type a name for the new list..."));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     newListNameLineEdit->setClearButtonEnabled(true);
-#endif
     connect(newListNameLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(enableDisableCreateButton(QString)));
     connect(newListNameLineEdit, SIGNAL(returnPressed()),
@@ -88,7 +86,8 @@ ListsManager::ListsManager(PumpController *pumpController,
 
 
     this->newListDescTextEdit = new QTextEdit(this);
-    newListDescTextEdit->setToolTip(tr("Type an optional description here"));
+    newListDescTextEdit->setPlaceholderText(tr("Type an optional description here"));
+    newListDescTextEdit->setToolTip(newListDescTextEdit->placeholderText());
     newListDescTextEdit->setTabChangesFocus(true);
 
 
