@@ -39,8 +39,8 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
 
     closeAction = new QAction(this);    
     closeAction->setShortcuts(closeShortcuts);
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
 
@@ -53,15 +53,15 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
                                                    QIcon(":/images/button-delete.png")),
                                   tr("Clear &Log"),
                                   this);
-    connect(clearButton, SIGNAL(clicked()),
-            logTextBrowser, SLOT(clear()));
+    connect(clearButton, &QAbstractButton::clicked,
+            logTextBrowser, &QTextEdit::clear);
 
     closeButton = new QPushButton(QIcon::fromTheme("window-close",
                                                    QIcon(":/images/button-close.png")),
                                   tr("&Close"),
                                   this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
 
     // Layout
