@@ -29,19 +29,9 @@
 
 
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-void customMessageHandlerQt4(QtMsgType type, const char *msg)
-{
-    // do nothing
-    Q_UNUSED(type)
-    Q_UNUSED(msg)  // FIXME, memory leak?
-
-    return;
-}
-#else
-void customMessageHandlerQt5(QtMsgType type,
-                             const QMessageLogContext &context,
-                             const QString &msg)
+void customMessageHandler(QtMsgType type,
+                          const QMessageLogContext &context,
+                          const QString &msg)
 {
     Q_UNUSED(type)
     Q_UNUSED(context)
@@ -51,7 +41,6 @@ void customMessageHandlerQt5(QtMsgType type,
 
     return;
 }
-#endif
 
 
 
@@ -59,7 +48,7 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.3.7");
+    dianaraApp.setApplicationVersion("1.4.0");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
@@ -115,7 +104,9 @@ int main(int argc, char *argv[])
                 std::cout << "    " << argv[0] << " [options]\n\n";
                 std::cout << "Options:\n";
                 std::cout << "    -c  --config [name]       Use a different "
-                             "configuration file and data folder\n";
+                             "configuration file and data folder\n"
+                             "                              (parameter is a "
+                             "simple name, not a file path)\n";
                 std::cout << "    -d  --debug               Show debug messages "
                              "in the terminal\n";
                 std::cout << "        --linkcolor=[color]   Set color for "
@@ -217,10 +208,12 @@ int main(int argc, char *argv[])
                 ignoreSslErrors = true;
                 cmdLine.removeAll(argument);
 
-                std::cout << "*************************************\n"
+                std::cout << "\n"
+                             "*************************************\n"
                              "*** WARNING: Ignoring SSL errors. ***\n"
                              "***          This is insecure!    ***\n"
-                             "*************************************\n";
+                             "*************************************\n"
+                             "\n";
             }
 
         } // End foreach
@@ -235,12 +228,7 @@ int main(int argc, char *argv[])
     #endif
 
         std::cout << "To see debug messages while running, use --debug\n";
-
-    #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        qInstallMsgHandler(customMessageHandlerQt4);
-    #else
-        qInstallMessageHandler(customMessageHandlerQt5);
-    #endif
+        qInstallMessageHandler(customMessageHandler);
     }
 
 
