@@ -44,11 +44,9 @@
 #include <QScrollBar>
 #include <QVariantList>
 #include <QDesktopServices>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QStandardPaths>
-#endif
 #include <QTime>
-#include <QSplitter>
+#include <QDockWidget>
 #include <QPainter>
 #include <QSessionManager>
 
@@ -109,6 +107,7 @@ public:
     void setTrayIconPixmap(int newCount = 0, int highlightedCount = 0);
 
     void loadSettings();
+    void loadMainWindowConfig();
     void saveSettings();
 
     void enableIgnoringSslErrors();
@@ -166,7 +165,7 @@ public slots:
                               int newPostCount, int highlightCount,
                               int directPostCount, int hlByFilterCount,
                               int deletedPostCount, int filteredPostCount,
-                              int pendingPostCount);
+                              int pendingPostCount, QString currentPage);
     void setTimelineTabTitle(PumpController::requestTypes timelineType,
                              int newPostCount,
                              int highlightCount,
@@ -197,6 +196,7 @@ public slots:
                           QIcon userAvatar, QString userOutbox);
 
 
+    void toggleLockedPanels(bool locked);
     void toggleSidePanel(bool shown);
     void toggleToolbar(bool shown);
     void toggleStatusBar(bool shown);
@@ -252,6 +252,7 @@ private:
     QAction *sessionPostNote;
     QAction *sessionQuit;
 
+    QAction *viewLockPanels;
     QAction *viewSidePanel;
     QAction *viewToolbar;
     QAction *viewStatusBar;
@@ -292,8 +293,8 @@ private:
     QProgressBar *initializationProgressBar;
 
 
-    QSplitter *mainSplitter;
-
+    QDockWidget *sideDockWidget;
+    QWidget *sideDockTitleWidget;
     QWidget *leftSideWidget;
     QVBoxLayout *leftLayout;
 
@@ -388,8 +389,7 @@ private:
 
     // Statusbar stuff
     QString oldStatusBarMessage;
-    QString previousStatusMessageFromTimeline;
-    QString previousStatusMessageFromMinorFeed;
+    QString previousStatusFeedInfo;
 
     // user account-related data
     QString userID;
