@@ -81,7 +81,7 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(1, 1, 1, 1);
     mainLayout->addWidget(getPendingButton);
-    mainLayout->addLayout(itemsLayout);
+    mainLayout->addLayout(itemsLayout, 1);
     mainLayout->addSpacing(8);
     mainLayout->addStretch();
     mainLayout->addWidget(getOlderButton);
