@@ -48,6 +48,9 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     QString authorId = activity->author()->getId();
 
+    this->itemIsOwn = (authorId == pController->currentUserId());
+
+
     avatarButton = new AvatarButton(activity->author(),
                                     this->pController,
                                     this->globalObj,
@@ -114,8 +117,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     activityDescriptionLabel->setAlignment(Qt::AlignTop);
     activityDescriptionLabel->setSizePolicy(QSizePolicy::Ignored,
                                             QSizePolicy::MinimumExpanding);
-    connect(activityDescriptionLabel, SIGNAL(linkHovered(QString)),
-            this, SLOT(showUrlInfo(QString)));
+    connect(activityDescriptionLabel, &QLabel::linkHovered,
+            this, &MinorFeedItem::showUrlInfo);
 
     // Tooltip contents
     QString activityTooltip = activity->generateTooltip();
@@ -261,8 +264,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
                                   QSizePolicy::Maximum);
         openButton->setToolTip("<b></b>"
                                + tr("Open referenced post"));
-        connect(openButton, SIGNAL(clicked()),
-                this, SLOT(openOriginalPost()));
+        connect(openButton, &QAbstractButton::clicked,
+                this, &MinorFeedItem::openOriginalPost);
         leftLayout->addWidget(openButton, 0, Qt::AlignHCenter);
     }
 
@@ -297,14 +300,56 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     topLayout = new QHBoxLayout();
     topLayout->setContentsMargins(0, 0, 0, 0);
-    if (authorId == pController->currentUserId())
+
+    int iconSpacing = 0;
+    this->verbIconType = globalObj->getMfIconType();
+
+    if (verbIconType != 0)
+    {
+        this->verbIcons = MiscHelpers::iconsForActivity(activity->getVerb());
+
+        // Handle the different styles to prepare the paintEvent()
+        this->verbIconSize = globalObj->getMfAvatarSize().width();
+        this->verbIconSizeSubtle = verbIconSize * 1.4;
+
+        if (verbIconType == 1 || verbIconType == 3)
+        {
+            iconSpacing = verbIconSize;
+        }
+        else
+        {
+            iconSpacing = verbIconSizeSubtle / 2;
+        }
+    }
+
+    if (itemIsOwn) // For our items, text first
     {
         topLayout->addLayout(rightLayout, 20);
-        topLayout->addLayout(leftLayout,  1);
+
+        if (verbIconType < 3) // 1 and 2 are icon-first (and this is reversed)
+        {
+            topLayout->addLayout(leftLayout, 1);
+            topLayout->addSpacing(iconSpacing);
+        }
+        else                  // 3 and 4 are avatar-first
+        {
+            topLayout->addSpacing(iconSpacing);
+            topLayout->addLayout(leftLayout, 1);
+        }
     }
-    else // Normal item, not ours
+    else // Normal item, not ours, layout with avatar/icon first
     {
-        topLayout->addLayout(leftLayout,  1);
+        if (verbIconType < 3) // 1 and 2 are icon-first
+        {
+            topLayout->addSpacing(iconSpacing);
+            topLayout->addLayout(leftLayout, 1);
+        }
+        else
+        {
+            topLayout->addLayout(leftLayout, 1);
+            topLayout->addSpacing(iconSpacing);
+        }
+
         topLayout->addLayout(rightLayout, 20);
     }
 
@@ -459,8 +504,8 @@ void MinorFeedItem::openOriginalPost()
                                     globalObj,
                                     nullptr); // Make it an independent window
     referencedPost->show();
-    connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
-            referencedPost, SLOT(setAllComments(QVariantList,QString)));
+    connect(pController, &PumpController::commentsReceived,
+            referencedPost, &Post::setAllComments);
     referencedPost->requestCommenterComments();
 }
 
@@ -515,3 +560,65 @@ void MinorFeedItem::leaveEvent(QEvent *event)
 
     event->accept();
 }
+
+
+void MinorFeedItem::paintEvent(QPaintEvent *event)
+{
+    if (verbIconType == 0 || verbIcons.size() < 2)
+    {
+        // Set not to show activity icons, or icon definitions are wrong
+        event->ignore();
+        return;
+    }
+
+    //////////// FIXME - TODO -- This needs a lot of optimizing all around
+
+    QIcon icon = QIcon::fromTheme(verbIcons.first(),
+                                  QIcon(verbIcons.last()));
+
+    bool subtle = false;
+    if (verbIconType == 2 || verbIconType == 4)
+    {
+        subtle = true;
+    }
+
+    QPixmap iconPixmap;
+    int iconOffset = 0;
+    if (subtle)
+    {
+        iconPixmap = icon.pixmap(verbIconSizeSubtle, verbIconSizeSubtle);
+        if (verbIconType == 4) // icon-after, subtle
+        {
+            iconOffset =  verbIconSize / 2; // Based on original icon size
+        }
+    }
+    else
+    {
+        iconPixmap = icon.pixmap(verbIconSize, verbIconSize);
+        if (verbIconType == 3) // icon-after
+        {
+            iconOffset = verbIconSize + this->topLayout->spacing();
+        }
+    }
+
+
+    int iconPos;
+    if (itemIsOwn)
+    {
+        iconPos = this->width() - iconPixmap.width() - iconOffset;
+    }
+    else
+    {
+        iconPos = 0 + iconOffset;
+    }
+
+    QPainter painter(this);
+    if (subtle)
+    {
+        painter.setOpacity(0.3);
+    }
+
+    painter.drawPixmap(iconPos, 0, iconPixmap);
+
+    event->accept();
+}
