@@ -75,6 +75,7 @@ public slots:
 protected:
     virtual void mousePressEvent(QMouseEvent *event);
     virtual void leaveEvent(QEvent *event);
+    virtual void paintEvent(QPaintEvent *event);
 
 
 private:
@@ -87,6 +88,12 @@ private:
     QVBoxLayout *rightLayout;
     QHBoxLayout *rightLowerLayout;
 
+
+    int verbIconType;
+    QStringList verbIcons;
+    int verbIconSize;
+    int verbIconSizeSubtle;
+
     AvatarButton *avatarButton;
     QLabel *timestampLabel;
     QLabel *activityDescriptionLabel;
@@ -101,6 +108,7 @@ private:
 
     FilterMatchesWidget *filterMatchesWidget;
 
+    bool itemIsOwn;
     bool itemIsNew;
     int itemHighlightType;
     QString createdAtTimestamp;
