@@ -34,11 +34,7 @@ QString MiscHelpers::getCachedAvatarFilename(QString url)
 
     if (!url.isEmpty())
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-#else
         localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
-#endif
         localFilename.append("/avatars/");
         localFilename.append(url.trimmed().toUtf8().toBase64());
 
@@ -79,11 +75,7 @@ QString MiscHelpers::getCachedImageFilename(QString url)
         base64url.truncate(255); // Limit filename length! Just in case the URL is VERY long
                                  // 255 chars is the limit in Ext3 FS
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-#else
         localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
-#endif
         localFilename.append("/images/");
         localFilename.append(base64url);
     }
@@ -100,7 +92,8 @@ QString MiscHelpers::getCachedImageFilename(QString url)
 QString MiscHelpers::getSuggestedFilename(QString authorId,
                                           QString postType,
                                           QString postTitle,
-                                          QString fileUrl)
+                                          QString fileUrl,
+                                          QString mimeType)
 {
     // Get original filename in server
     QString originalFilename = fileUrl.split("/").last();
@@ -126,7 +119,24 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
 
     suggestedFilename.append("_" + originalFilename); // Something like A53r2w.png
 
-    // Extension will be .bin for generic files, at the moment
+
+    // Extension for 'file' attachments is given as .bin by server, for now
+    if (postType == "file") // so determine a proper one based on mime info
+    {
+        QMimeDatabase mimeDb;
+        QMimeType mime = mimeDb.mimeTypeForName(mimeType);
+
+        QString suggestedExtension = mime.preferredSuffix();
+        if (!suggestedExtension.isEmpty())
+        {
+            if (suggestedFilename.endsWith(".bin"))
+            {
+                suggestedFilename.remove(-3, 3);
+            }
+
+            suggestedFilename.append(suggestedExtension);
+        }
+    }
 
     return suggestedFilename;
 }
@@ -136,41 +146,17 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
 /*
  * Return MIME content type, like image/png, audio/ogg, etc.
  *
- * using libmagic
- *
  */
 QString MiscHelpers::getFileMimeType(QString fileUri)
 {
     qDebug() << "getFileMimeType() file:" << fileUri;
 
-    magic_t magicCookie = magic_open(MAGIC_MIME_TYPE);
-    if (magicCookie == NULL)
-    {
-        qDebug() << "libmagic init error!";
-        return QString();
-    }
+    QMimeDatabase mimeDb;
+    QMimeType mimeType = mimeDb.mimeTypeForFile(fileUri);
+    qDebug() << mimeType.name();
+    qDebug() << mimeType.aliases();
 
-    if (magic_load(magicCookie, NULL) != 0)
-    {
-        qDebug() << "magic_load() error! No system-wide libmagic DB?";
-        // Try loading from a subdirectory instead (in mswindows, maybe osx)
-        if (magic_load(magicCookie, "plugins/magic") != 0)
-        {
-            qDebug() << "magic_load() error; Can't load plugins/magic.mgc";
-            magic_close(magicCookie);
-            return QString();
-        }
-    }
-
-    const char *magicMimeString;
-    magicMimeString = magic_file(magicCookie, fileUri.toLocal8Bit());
-
-    QString mimeType = QString(magicMimeString);
-    qDebug() << "File MIME type:" << mimeType;
-
-    magic_close(magicCookie);
-
-    return mimeType;
+    return mimeType.name(); // mime.aliases() is also interesting
 }
 
 
@@ -209,6 +195,98 @@ bool MiscHelpers::isImageAnimated(QString fileUri)
     return isAnimated;
 }
 
+/*
+ * Get a pair of icon-name + fallback-image for the given activity verb
+ *
+ */
+QStringList MiscHelpers::iconsForActivity(QString verb)
+{
+    QVariantMap iconMap;
+    iconMap.insert("like",            QStringList("emblem-favorite")
+                                       << ":/images/button-like.png");
+    iconMap.insert("unlike",          QStringList("emblem-favorite")
+                                       << ":/images/button-like.png");
+    iconMap.insert("favorite",        QStringList("emblem-favorite")
+                                       << ":/images/button-like.png");
+    iconMap.insert("unfavorite",      QStringList("emblem-favorite")
+                                       << ":/images/button-like.png");
+
+    iconMap.insert("unshare",         QStringList("dialog-cancel")
+                                       << ":/images/button-cancel.png");
+
+    iconMap.insert("post",            QStringList("mail-send")
+                                       << ":/images/button-post.png");
+
+    iconMap.insert("update",          QStringList("view-refresh")
+                                       << ":/images/menu-refresh.png");
+
+    iconMap.insert("follow",          QStringList("list-add-user")
+                                       << ":/images/list-add.png");
+    iconMap.insert("stop-following",  QStringList("list-remove-user")
+                                       << ":/images/list-remove.png");
+
+    iconMap.insert("add",             QStringList("list-add")
+                                       << ":/images/list-add.png");
+    iconMap.insert("remove",          QStringList("list-remove")
+                                       << ":/images/list-remove.png");
+
+    iconMap.insert("create",         QStringList("document-new") // FIXME; also -edit?
+                                      << ":/images/button-edit.png");
+    iconMap.insert("delete",         QStringList("edit-delete")
+                                      << ":/images/button-delete.png");
+
+    iconMap.insert("join",           QStringList("user-group-new")
+                                      << ":/images/button-online.png");
+    iconMap.insert("leave",          QStringList("user-group-delete")
+                                      << ":/images/button-close.png");
+
+    QStringList missingIconList;
+    missingIconList.append("dialog-information");
+    missingIconList.append(":/images/image-missing.png");
+
+
+    return iconMap.value(verb, missingIconList).toStringList();
+}
+
+
+const QStringList MiscHelpers::imageExtensions()
+{
+    return QStringList() << "png" << "jpg"  << "jpeg" << "jpe" << "gif"
+                         << "mng" << "webp" << "svg";
+}
+
+const QStringList MiscHelpers::audioExtensions()
+{
+    return QStringList() << "ogg" << "oga"  << "flac" << "opus" << "mka"
+                         << "mp3" << "mpga" << "wav"  << "wma"  << "asf" ;
+}
+
+const QStringList MiscHelpers::videoExtensions()
+{
+    return QStringList() << "mkv" << "mpg" << "mpeg" << "mpe" << "mpv"
+                         << "ogm" << "ogg" << "mp4"  << "avi" << "webm"
+                         << "mov" << "flv" << "3gp"  << "wmv" << "asf";
+}
+
+/*
+ * Return a file filter string, usable in file dialogs,
+ * such as: (*.png *.jpg *.gif);;
+ *
+ */
+const QString MiscHelpers::fileFilterString(QStringList extensions)
+{
+    QString filterString = " (";
+    foreach (QString extension, extensions)
+    {
+        filterString.append(" *." + extension + " ");
+    }
+
+    filterString.append(");;");
+
+    return filterString;
+}
+
+
 
 
 QString MiscHelpers::fixLongName(QString name)
@@ -307,7 +385,22 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
         //qDebug() << "Matched length is:" << matchedLength;
 
         imgSrc = regExp.cap(3);
-        if (!imgSrc.isEmpty()) // if not an empty string, add to the list, and replace HTML
+
+        // Protection: ensure the <img> tag doesn't point to a huge video
+        foreach (QString extension, videoExtensions())
+        {
+            if (imgSrc.endsWith(extension))
+            {
+                qDebug() << "*** Ignoring IMG tag that points to a video!! ***";
+                qDebug() << "*** " << imgSrc;
+                imgSrc.clear(); // Avoid getting it into the download list
+                break;
+            }
+        }
+
+        // If not an empty string, originally or due to video extension,
+        // add to the list, and replace HTML
+        if (!imgSrc.isEmpty())
         {
             // If the url had parameters, they _might_ have &amp; in place of "&"
             imgSrc.replace("&amp;", "&"); // Put them back
@@ -324,7 +417,12 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
             QString cachedImageFilename = getCachedImageFilename(imgSrc);
 
             int imageWidth = getImageWidth(cachedImageFilename);
-            // if width is bigger than the post, make it smaller to fit
+            if (imageWidth <= 0) // If we still don't have a cached file,
+            {
+                imageWidth = 32; // set a typical icon size
+            }
+
+            // If width is bigger than the post, make it smaller to fit
             if (imageWidth > postWidth - 32)
             {
                 // Some margins, to account for a scrollbar or a tab space before the image
@@ -407,6 +505,10 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
 
     // FIXME: Maybe try to remove background colors from <p> elements
 
+    // Remove these elements created by some QTextBlocks
+    cleanHtml.remove("<!--StartFragment-->");
+    cleanHtml.remove("<!--EndFragment-->");
+
     cleanHtml.remove("</body></html>");
 
     return cleanHtml.trimmed();
@@ -465,7 +567,7 @@ QString MiscHelpers::quotedText(QString author, QString content)
     content.replace(">", "&gt;");
     content.replace("\n", "<br>"); // Important to replace this AFTER < and >
 
-    QString quoteHtml = "&gt;&gt; <b><u>"+ author + ":</u></b>"  // >> + name
+    QString quoteHtml = "&raquo; <b><u>"+ author + "</u></b>:"  // >> + name
                         "<blockquote>"
                         "<small><i>&ldquo;" + content + "&rdquo;</i></small>"
                         "</blockquote> <br>";
@@ -546,3 +648,25 @@ QString MiscHelpers::mediaHtmlBase(QString postType,
 
     return html;
 }
+
+/*
+ * Open URL in system's browser, showing a proper error message if that fails
+ *
+ */
+bool MiscHelpers::openUrl(QUrl url, QWidget *parentWidget)
+{
+    bool browserLaunched = QDesktopServices::openUrl(url);
+
+    if (!browserLaunched)
+    {
+        QMessageBox::warning(parentWidget,
+                             tr("Error: Unable to launch browser"),
+                             tr("The default system web browser could not "
+                                "be executed.")
+                             + "<br /><br />"
+                             + tr("You might need to install the "
+                                  "XDG utilities."));
+    }
+
+    return browserLaunched;
+}
