@@ -38,33 +38,33 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     this->pageNumberSpinbox = new QSpinBox(this);
     pageNumberSpinbox->setRange(1, 1); // 1 to totalPages, but initially 1-1
     pageNumberSpinbox->setValue(1);
-    connect(pageNumberSpinbox, SIGNAL(editingFinished()),
-            this, SLOT(onPageNumberEntered()));
+    connect(pageNumberSpinbox, &QAbstractSpinBox::editingFinished,
+            this, &PageSelector::onPageNumberEntered);
 
-    this->rangeLabel = new QLabel(this);
+    this->rangeLabel = new QLabel(this); // [ 1 ~ ### ]
 
 
     this->firstButton = new QPushButton(QIcon::fromTheme("go-first-view-page",
                                                             QIcon(":/images/button-previous.png")),
                                            tr("&First", "As in: first page"),
                                            this);
-    connect(firstButton, SIGNAL(clicked()),
-            this, SLOT(setToFirstPage()));
+    connect(firstButton, &QAbstractButton::clicked,
+            this, &PageSelector::setToFirstPage);
 
     this->lastButton = new QPushButton(QIcon::fromTheme("go-last-view-page",
                                                             QIcon(":/images/button-next.png")),
                                            tr("&Last", "As in: last page"),
                                            this);
-    connect(lastButton, SIGNAL(clicked()),
-            this, SLOT(setToLastPage()));
+    connect(lastButton, &QAbstractButton::clicked,
+            this, &PageSelector::setToLastPage);
 
 
     // Middle
     this->newerButton = new QPushButton("< " + tr("Newer",
                                                   "As in: newer pages"),
                                         this);
-    connect(newerButton, SIGNAL(clicked(bool)),
-            this, SLOT(decreasePage()));
+    connect(newerButton, &QAbstractButton::clicked,
+            this, &PageSelector::decreasePage);
 
     this->pageNumberSlider = new QSlider(Qt::Horizontal, this);
     pageNumberSlider->setRange(1, 1);  // Initially
@@ -73,19 +73,19 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
 
 
     // Make spinbox and slider keep in sync
-    connect(pageNumberSlider, SIGNAL(valueChanged(int)),
-            pageNumberSpinbox, SLOT(setValue(int)));
+    connect(pageNumberSlider, &QAbstractSlider::valueChanged,
+            pageNumberSpinbox, &QSpinBox::setValue);
 
     // And also enable/disable buttons depending on current page
-    connect(pageNumberSpinbox, SIGNAL(valueChanged(int)),
+    connect(pageNumberSpinbox, SIGNAL(valueChanged(int)), // Old-style, overload
             this, SLOT(onPageNumberChanged(int)));
 
 
     this->olderButton = new QPushButton(tr("Older",
                                            "As in: older pages") + " >",
                                         this);
-    connect(olderButton, SIGNAL(clicked(bool)),
-            this, SLOT(increasePage()));
+    connect(olderButton, &QAbstractButton::clicked,
+            this, &PageSelector::increasePage);
 
 
 
@@ -95,22 +95,22 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
                                      "  " + tr("&Go") + " >>  ",
                                      this);
     goButton->setDisabled(true);
-    connect(goButton, SIGNAL(clicked()),
-            this, SLOT(goToPage()));
+    connect(goButton, &QAbstractButton::clicked,
+            this, &PageSelector::goToPage);
 
 
     this->closeButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                          QIcon(":/images/button-cancel.png")),
                                         tr("&Cancel"),
                                         this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
 
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
 
