@@ -28,25 +28,24 @@ PeopleWidget::PeopleWidget(QString buttonText,
     this->setMinimumSize(120, 120);
 
     this->pController = pumpController;
-    connect(pController, SIGNAL(contactListReceived(QString,QVariantList,int)),
-            this, SLOT(updateAllContactsList(QString,QVariantList,int)));
+    connect(pController, &PumpController::contactListReceived,
+            this, &PeopleWidget::updateAllContactsList);
 
-    connect(pController, SIGNAL(contactFollowed(ASPerson*)),
-            this, SLOT(addContact(ASPerson*)));
-    connect(pController, SIGNAL(contactUnfollowed(ASPerson*)),
-            this, SLOT(removeContact(ASPerson*)));
+    connect(pController, &PumpController::contactFollowed,
+            this, &PeopleWidget::addContact);
+    connect(pController, &PumpController::contactUnfollowed,
+            this, &PeopleWidget::removeContact);
 
 
     this->searchLabel = new QLabel(tr("&Search:"), this);
 
     this->searchLineEdit = new QLineEdit(this);
     searchLineEdit->setPlaceholderText(tr("Enter a name here to search for it"));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     searchLineEdit->setClearButtonEnabled(true);
-#endif
+
     searchLabel->setBuddy(searchLineEdit);
-    connect(searchLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(filterList(QString)));
+    connect(searchLineEdit, &QLineEdit::textChanged,
+            this, &PeopleWidget::filterList);
 
 
     itemModel = new QStandardItemModel(this);
@@ -62,16 +61,16 @@ PeopleWidget::PeopleWidget(QString buttonText,
     allContactsListView->setDragDropMode(QListView::DragDrop);
     allContactsListView->setDefaultDropAction(Qt::CopyAction);
     allContactsListView->setModel(filterModel);
-    connect(allContactsListView, SIGNAL(activated(QModelIndex)),
-            this, SLOT(returnClickedContact(QModelIndex)));
+    connect(allContactsListView, &QAbstractItemView::activated,
+            this, &PeopleWidget::returnClickedContact);
 
 
     addToButton = new QPushButton(QIcon::fromTheme("list-add",
                                                    QIcon(":/images/list-add.png")),
                                   buttonText,
                                   this);
-    connect(addToButton, SIGNAL(clicked()),
-            this, SLOT(returnContact()));
+    connect(addToButton, &QAbstractButton::clicked,
+            this, &PeopleWidget::returnContact);
 
 
 
@@ -91,7 +90,7 @@ PeopleWidget::PeopleWidget(QString buttonText,
     {
         //allContactsListWidget->setSelectionMode(QListView::ExtendedSelection);
 
-        // FIXME 1.3.x: For now, Single selection mode in both cases
+        // FIXME 1.4.x: For now, Single selection mode in both cases
         allContactsListView->setSelectionMode(QListView::SingleSelection);
     }
     else     // StandaloneWidget
@@ -108,8 +107,8 @@ PeopleWidget::PeopleWidget(QString buttonText,
                                                         QIcon(":/images/button-cancel.png")),
                                        tr("&Cancel"),
                                        this);
-        connect(cancelButton, SIGNAL(clicked()),
-                this, SLOT(hide()));
+        connect(cancelButton, &QAbstractButton::clicked,
+                this, &QWidget::hide);
         mainLayout->addWidget(cancelButton);
     }
 
