@@ -791,7 +791,8 @@ Post::Post(ASActivity *activity,
         QString suggestedFilename = MiscHelpers::getSuggestedFilename(this->postAuthorId,
                                                                       this->postType,
                                                                       this->postTitle,
-                                                                      this->postAttachmentPureUrl);
+                                                                      this->postAttachmentPureUrl,
+                                                                      this->postFileMimeType);
         this->downloadWidget = new DownloadWidget(attachmentUrl,
                                                   suggestedFilename,
                                                   this->pController,
@@ -1178,11 +1179,37 @@ void Post::setPostContents()
     // Attached file
     if (!this->postFileUrl.isEmpty())
     {
+        QByteArray iconDataUri;
+
+        QMimeDatabase mimeDb;
+        QMimeType mimeType = mimeDb.mimeTypeForName(this->postFileMimeType);
+        const QString mimeIcon = mimeType.iconName();
+
+        if (QIcon::hasThemeIcon(mimeIcon))
+        {
+            QPixmap mimePixmap = QIcon::fromTheme(mimeIcon).pixmap(128, 128);
+            QBuffer mimeBuffer;
+            mimeBuffer.open(QIODevice::WriteOnly);
+            mimePixmap.save(&mimeBuffer, "PNG");
+
+            // Compose a "Data URI" with the icon-as-png data
+            iconDataUri = "data:image/png;base64,"
+                        + mimeBuffer.buffer().toBase64();
+
+            mimeBuffer.close();
+        }
+        else
+        {
+            iconDataUri = ":/images/attached-file.png";
+        }
+
         postMediaHtml = MiscHelpers::mediaHtmlBase(this->postType,
-                                                   ":/images/attached-file.png",
+                                                   iconDataUri,
                                                    this->downloadAttachmentString,
                                                    tr("Attached File")
-                                                   + ": " + postFileMimeType);
+                                                   + QString(": %1 (%2)")
+                                                     .arg(mimeType.comment(),
+                                                          postFileMimeType));
     }
 
 
@@ -2045,7 +2072,7 @@ void Post::openClickedUrl(QUrl url)
     else
     {
         qDebug() << "Opening this link in browser";
-        QDesktopServices::openUrl(url);
+        MiscHelpers::openUrl(url, this);
     }
 }
 
@@ -2086,7 +2113,7 @@ void Post::showHighlightedUrl(QString url)
 
 void Post::openPostInBrowser()
 {
-    QDesktopServices::openUrl(this->postUrl);
+    MiscHelpers::openUrl(this->postUrl, this);
 }
 
 void Post::copyPostUrlToClipboard()
