@@ -66,8 +66,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
                                                          QIcon(":/images/button-post.png")),
                                         tr("Change &E-mail..."),
                                         this);
-    connect(changeEmailButton, SIGNAL(clicked()),
-            emailChanger, SLOT(show()));
+    connect(changeEmailButton, &QAbstractButton::clicked,
+            emailChanger, &QWidget::show);
 
 
     avatarLabel = new QLabel(this);
@@ -78,8 +78,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     changeAvatarButton = new QPushButton(QIcon::fromTheme("folder-image-people"),
                                          tr("Change &Avatar..."),
                                          this);
-    connect(changeAvatarButton, SIGNAL(clicked()),
-            this, SLOT(findAvatarFile()));
+    connect(changeAvatarButton, &QAbstractButton::clicked,
+            this, &ProfileEditor::findAvatarFile);
 
     this->avatarChanged = false;
 
@@ -87,19 +87,19 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     fullNameLineEdit = new QLineEdit(this);
     fullNameLineEdit->setToolTip("<b></b>"
                                  + tr("This is your visible name"));
-    connect(fullNameLineEdit, SIGNAL(textEdited(QString)),
-            this, SLOT(enableSaveButton()));
+    connect(fullNameLineEdit, &QLineEdit::textEdited,
+            this, &ProfileEditor::enableSaveButton);
 
     hometownLineEdit = new QLineEdit(this);
-    connect(hometownLineEdit, SIGNAL(textEdited(QString)),
-            this, SLOT(enableSaveButton()));
+    connect(hometownLineEdit, &QLineEdit::textEdited,
+            this, &ProfileEditor::enableSaveButton);
 
     bioTextEdit = new QTextEdit(this);
     bioTextEdit->setTabChangesFocus(true);
     bioTextEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
                                QSizePolicy::MinimumExpanding);
-    connect(bioTextEdit, SIGNAL(textChanged()),
-            this, SLOT(enableSaveButton()));
+    connect(bioTextEdit, &QTextEdit::textChanged,
+            this, &ProfileEditor::enableSaveButton);
 
 
     newAvatarInfoLabel = new QLabel("\n"
@@ -122,22 +122,22 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
                                                   QIcon(":/images/button-save.png")),
                                  tr("&Save Profile"),
                                  this);
-    connect(saveButton, SIGNAL(clicked()),
-            this, SLOT(saveProfile()));
+    connect(saveButton, &QAbstractButton::clicked,
+            this, &ProfileEditor::saveProfile);
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(close()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::close);
 
 
     // ESC to cancel, too
     cancelAction = new QAction(this);
     cancelAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(cancelAction, SIGNAL(triggered()),
-            this, SLOT(close()));
+    connect(cancelAction, &QAction::triggered,
+            this, &QWidget::close);
     this->addAction(cancelAction);
 
 
@@ -267,7 +267,8 @@ void ProfileEditor::findAvatarFile()
                                                      tr("Select avatar image"),
                                                      QDir::homePath(),
                                                      tr("Image files")
-                                                     + " (*.png *.jpg *.jpeg *.gif);;"
+                                                     + " (*.png *.jpg *.jpe "
+                                                       "*.jpeg *.gif);;"
                                                      + tr("All files") + " (*)");
 
     if (!newAvatarFilename.isEmpty())
@@ -305,8 +306,8 @@ void ProfileEditor::saveProfile()
 {
     if (avatarChanged)
     {
-        connect(pController, SIGNAL(avatarUploaded(QString)),
-                this, SLOT(sendProfileData(QString)));
+        connect(pController, &PumpController::avatarUploaded,
+                this, &ProfileEditor::sendProfileData);
 
         this->pController->uploadFile(this->newAvatarFilename,
                                       this->newAvatarContentType,
@@ -324,8 +325,8 @@ void ProfileEditor::sendProfileData(QString newImageUrl)
 {
     if (avatarChanged)
     {
-        disconnect(pController, SIGNAL(avatarUploaded(QString)),
-                   this, SLOT(sendProfileData(QString)));
+        disconnect(pController, &PumpController::avatarUploaded,
+                   this, &ProfileEditor::sendProfileData);
 
         this->avatarChanged = false; // For next time the dialog is shown
         this->newAvatarInfoLabel->hide();
