@@ -48,8 +48,8 @@ ProxyDialog::ProxyDialog(int proxyType,
 
     authCheckBox = new QCheckBox(this);
     authCheckBox->setChecked(useAuth);
-    connect(authCheckBox, SIGNAL(toggled(bool)),
-            this, SLOT(toggleAuth(bool)));
+    connect(authCheckBox, &QAbstractButton::toggled,
+            this, &ProxyDialog::toggleAuth);
 
     userLineEdit = new QLineEdit(user, this);
     userLineEdit->setPlaceholderText(tr("Your proxy username"));
@@ -74,22 +74,22 @@ ProxyDialog::ProxyDialog(int proxyType,
                                                   QIcon(":/images/button-save.png")),
                                  tr("&Save"),
                                  this);
-    connect(saveButton, SIGNAL(clicked()),
-            this, SLOT(saveSettings()));
+    connect(saveButton, &QAbstractButton::clicked,
+            this, &ProxyDialog::saveSettings);
 
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
                                    tr("&Cancel"),
                                    this);
-    connect(cancelButton, SIGNAL(clicked()),
-            this, SLOT(hide()));
+    connect(cancelButton, &QAbstractButton::clicked,
+            this, &QWidget::hide);
 
 
     // ESC to close
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
-    connect(closeAction, SIGNAL(triggered()),
-            this, SLOT(hide()));
+    connect(closeAction, &QAction::triggered,
+            this, &QWidget::hide);
     this->addAction(closeAction);
 
 
