@@ -50,8 +50,6 @@ Publisher::Publisher(PumpController *pumpController,
     this->defaultPublicPosting = false; // initialize
     this->showCharacterCounter = false;
 
-    this->setFocusPolicy(Qt::StrongFocus); // To keep the publisher from getting focus by accident
-
 
     this->audienceSelectorTo = new AudienceSelector(pController, "to", this);
     connect(audienceSelectorTo, SIGNAL(audienceSelected(QString,QStringList,QStringList)),
@@ -87,6 +85,8 @@ Publisher::Publisher(PumpController *pumpController,
     mediaInfoLabel = new QLabel(this);
     mediaInfoLabel->setWordWrap(true);
     mediaInfoLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
+    mediaInfoLabel->setSizePolicy(QSizePolicy::Ignored,
+                                  QSizePolicy::Preferred);
 
     selectMediaButton = new QPushButton(this);
     selectMediaButton->setSizePolicy(QSizePolicy::MinimumExpanding,
@@ -132,6 +132,8 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(addNickToRecipients(QString,QString,QString)));
     connect(composerBox, SIGNAL(textChanged()),
             this, SLOT(updateCharacterCounter()));
+    connect(composerBox, SIGNAL(fileDropped(QString)),
+            this, SLOT(onFileDropped(QString)));
 
     // Pressing Enter in title goes to message body
     connect(titleLineEdit, SIGNAL(returnPressed()),
@@ -306,6 +308,8 @@ Publisher::Publisher(PumpController *pumpController,
     audienceLabelsFont.setBold(false);
     audienceLabelsFont.setItalic(false);
     statusInfoLabel->setFont(audienceLabelsFont);
+    connect(composerBox, SIGNAL(errorHappened(QString)),
+            statusInfoLabel, SLOT(setText(QString)));
 
 
     // To send the post
@@ -381,6 +385,7 @@ Publisher::Publisher(PumpController *pumpController,
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
     mainLayout->addLayout(titleLayout,   0);
+    mainLayout->addSpacing(1);
     mainLayout->addLayout(mediaLayout,   0);
     mainLayout->addWidget(composerBox,   2);
     mainLayout->addLayout(buttonsLayout, 0);
@@ -654,9 +659,12 @@ void Publisher::setMinimumMode()
     // Disable Ctrl+Shift+V for plaintext paste, to avoid conflict with Commenters
     this->composerBox->setPlainPasteEnabled(false);
 
+    // Keep the publisher from getting focus via tab key, by accident
+    composerBox->setFocusPolicy(Qt::ClickFocus);
+
 
     // ~1 row
-    int composerHeight = composerBox->getMessageLabelHeight();
+    int composerHeight = titleLineEdit->fontInfo().pixelSize() * 2; // kinda TMP
     this->composerBox->setMinimumHeight(composerHeight);
     this->composerBox->setMaximumHeight(composerHeight);
 
@@ -785,6 +793,9 @@ void Publisher::setFullMode()
     // Re-enable ctrl+shift+V for plaintext paste (disabled to avoid conflicts)
     this->composerBox->setPlainPasteEnabled(true);
 
+    // Re-enable normal focus policy, while in full mode
+    this->composerBox->setFocusPolicy(Qt::StrongFocus);
+
     this->toSelectorButton->show();
     this->ccSelectorButton->show();
 
@@ -823,7 +834,7 @@ void Publisher::setFullMode()
 
 
 
-void Publisher::setPictureMode()
+void Publisher::setPictureMode(QString initialFileUrl)
 {
     postType = "image";
 
@@ -843,11 +854,11 @@ void Publisher::setPictureMode()
 
     pictureLabel->setToolTip(tr("Picture not set"));
 
-    this->findMediaFile(); // Show the open file dialog directly
+    this->findMediaFile(initialFileUrl); // Show the open file dialog directly
 }
 
 
-void Publisher::setAudioMode()
+void Publisher::setAudioMode(QString initialFileUrl)
 {
     postType = "audio";
     setMediaModeWidgets();
@@ -866,11 +877,11 @@ void Publisher::setAudioMode()
 
     pictureLabel->setToolTip(tr("Audio file not set"));
 
-    this->findMediaFile(); // Show the open file dialog directly
+    this->findMediaFile(initialFileUrl); // Show the open file dialog directly
 }
 
 
-void Publisher::setVideoMode()
+void Publisher::setVideoMode(QString initialFileUrl)
 {
     postType = "video";
 
@@ -890,10 +901,10 @@ void Publisher::setVideoMode()
 
     pictureLabel->setToolTip(tr("Video not set"));
 
-    this->findMediaFile(); // Show the open file dialog directly
+    this->findMediaFile(initialFileUrl); // Show the open file dialog directly
 }
 
-void Publisher::setFileMode()
+void Publisher::setFileMode(QString initialFileUrl)
 {
     postType = "file";
 
@@ -913,7 +924,36 @@ void Publisher::setFileMode()
 
     pictureLabel->setToolTip(tr("File not set"));
 
-    this->findMediaFile(); // Show the open file dialog directly
+    this->findMediaFile(initialFileUrl); // Show the open file dialog directly
+}
+
+/*
+ * Handle drag-and-drop for files.
+ *
+ * Determine which kind of file it is, and set the proper post type for it.
+ *
+ */
+void Publisher::onFileDropped(QString fileUrl)
+{
+    QString fileExtension = fileUrl;
+    fileExtension.remove(QRegExp(".*\\.")); // Remove all but the extension
+
+    if (MiscHelpers::imageExtensions().contains(fileExtension))
+    {
+        this->setPictureMode(fileUrl);
+    }
+    else if (MiscHelpers::audioExtensions().contains(fileExtension))
+    {
+        this->setAudioMode(fileUrl);
+    }
+    else if (MiscHelpers::videoExtensions().contains(fileExtension))
+    {
+        this->setVideoMode(fileUrl);
+    }
+    else
+    {
+        this->setFileMode(fileUrl);
+    }
 }
 
 
@@ -1458,7 +1498,7 @@ void Publisher::sendPost()
  * Let the user find a file in his/her folders, for media upload
  *
  */
-void Publisher::findMediaFile()
+void Publisher::findMediaFile(QString initialFileUrl)
 {
     QString findDialogTitle;
     QString mediaTypes;
@@ -1468,8 +1508,8 @@ void Publisher::findMediaFile()
     if (postType == "image")
     {
         findDialogTitle = tr("Select one image");
-        mediaTypes = tr("Image files") + " (*.png *.jpg *.jpeg *.jpe"
-                                         " *.gif *.mng *.webp *.svg);;";
+        mediaTypes = tr("Image files")
+                   + MiscHelpers::fileFilterString(MiscHelpers::imageExtensions());
 
         errorTitle =  tr("Invalid image");
         errorMessage = tr("The image format cannot be detected.\n"
@@ -1479,8 +1519,8 @@ void Publisher::findMediaFile()
     else if (postType == "audio")
     {
         findDialogTitle = tr("Select one audio file");
-        mediaTypes = tr("Audio files") + " (*.ogg *.oga *.flac *.mka"
-                                         " *.mp3 *.mpga *.wav *.wma);;";
+        mediaTypes = tr("Audio files")
+                   + MiscHelpers::fileFilterString(MiscHelpers::audioExtensions());
 
         errorTitle = tr("Invalid audio file");
         errorMessage = tr("The audio format cannot be detected.");
@@ -1488,9 +1528,8 @@ void Publisher::findMediaFile()
     else if (postType == "video")
     {
         findDialogTitle = tr("Select one video file");
-        mediaTypes = tr("Video files") + " (*.avi *.mpg *.mpeg *.mpe *.mpv"
-                                         " *.ogm *.ogg *.mkv *.mp4 *.webm"
-                                         " *.mov *.flv *.3gp *.wmv);;";
+        mediaTypes = tr("Video files")
+                   + MiscHelpers::fileFilterString(MiscHelpers::videoExtensions());;
 
         errorTitle = tr("Invalid video file");
         errorMessage = tr("The video format cannot be detected.");
@@ -1504,11 +1543,15 @@ void Publisher::findMediaFile()
         errorMessage = tr("The file type cannot be detected.");
     }
 
-    QString filename;
-    filename = QFileDialog::getOpenFileName(this, findDialogTitle,
-                                            this->lastUsedDirectory,
-                                            mediaTypes
-                                            + tr("All files") + " (*)");
+    QString filename = initialFileUrl;
+    if (filename.isEmpty())
+    {
+        filename = QFileDialog::getOpenFileName(this, findDialogTitle,
+                                                this->lastUsedDirectory,
+                                                mediaTypes
+                                                + tr("All files") + " (*)");
+    }
+
 
     if (!filename.isEmpty())
     {
@@ -1555,7 +1598,7 @@ void Publisher::findMediaFile()
                 {
                     QMessageBox::warning(this, errorTitle, errorMessage);
                 }
-                this->pictureLabel->setPixmap(imagePixmap.scaled(320, 180,  // 16:9
+                this->pictureLabel->setPixmap(imagePixmap.scaled(266, 150,  // 16:9
                                                                  Qt::KeepAspectRatio,
                                                                  Qt::SmoothTransformation));
                 metaDataString = "<br><br>"
@@ -1564,6 +1607,16 @@ void Publisher::findMediaFile()
                                  + MiscHelpers::resolutionString(imagePixmap.width(),
                                                                  imagePixmap.height());
             }
+            else
+            {
+                QMimeDatabase mimeDb;
+                const QString mimeIcon = mimeDb.mimeTypeForFile(filename).iconName();
+                if (QIcon::hasThemeIcon(mimeIcon))
+                {
+                    this->pictureLabel->setPixmap(QIcon::fromTheme(mimeIcon)
+                                                        .pixmap(150, 150));
+                }
+            }
 
             this->lastUsedDirectory = fileInfo.path();
             qDebug() << "last used directory:" << lastUsedDirectory;
