@@ -71,10 +71,11 @@ public slots:
     void setMinimumMode();
     void setFullMode();
 
-    void setPictureMode();
-    void setAudioMode();
-    void setVideoMode();
-    void setFileMode();
+    void setPictureMode(QString initialFileUrl = "");
+    void setAudioMode(QString initialFileUrl = "");
+    void setVideoMode(QString initialFileUrl = "");
+    void setFileMode(QString initialFileUrl = "");
+    void onFileDropped(QString fileUrl);
 
     void cancelMediaMode();
 
@@ -104,7 +105,7 @@ public slots:
 
     void sendPost();
 
-    void findMediaFile();
+    void findMediaFile(QString initialFileUrl = "");
     void updateProgressBar(qint64 sent, qint64 total);
 
     void updateCharacterCounter();
