@@ -25,9 +25,7 @@
 #include <QStringList>
 #include <QByteArray>
 #include <QUrl>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QUrlQuery>
-#endif
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QNetworkAccessManager>
@@ -45,14 +43,7 @@
 /// For JSON parsing
 #include <QVariant>
 #include <QVariantMap>
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-// Qt 4
-#include <qjson/parser.h>
-#include <qjson/serializer.h>
-#else
-// Qt 5
 #include <QJsonDocument>
-#endif
 
 // For OAuth authentication
 #include <QtOAuth>
@@ -182,7 +173,7 @@ public:
 
     void getListsList();
     void createPersonList(QString name, QString description);
-    void deletePersonList(QString id);
+    void deletePersonList(QString listId);
     void getPersonList(QString url);
     void addPersonToList(QString listId, QString personId);
     void removePersonFromList(QString listId, QString personId);
@@ -239,9 +230,12 @@ public:
 
 
 signals:
-    void openingAuthorizeURL(QUrl url);
+    void openingAuthorizeUrl(QUrl url, bool browserLaunched);
+    void authorizationSucceeded();
     void authorizationFailed(QString errorTitle, QString errorMessage);
     void authorizationStatusChanged(bool authorized);
+
+
     void initializationStepChanged(int step);
     void initializationCompleted();
 
