@@ -59,8 +59,8 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
                                                            QIcon(":/images/no-avatar.png")),
                                           tr("Get list of users from your server"),
                                           this);
-    connect(getListButton, SIGNAL(clicked()),
-            this, SLOT(getList()));
+    connect(getListButton, &QAbstractButton::clicked,
+            this, &SiteUsersList::getList);
 
 
     this->serverInfoLabel = new QLabel(this);
@@ -76,9 +76,14 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
                                             this);
     closeListButton->setSizePolicy(QSizePolicy::Maximum,
                                    QSizePolicy::Maximum);
-    closeListButton->setToolTip(tr("Close list"));
-    connect(closeListButton, SIGNAL(clicked()),
-            this, SLOT(closeList()));
+    closeListButton->setShortcut(QKeySequence("Ctrl+W"));
+    closeListButton->setToolTip(tr("Close list")
+                                + " ("
+                                + closeListButton->shortcut()
+                                  .toString(QKeySequence::NativeText)
+                                + ")");
+    connect(closeListButton, &QAbstractButton::clicked,
+            this, &SiteUsersList::closeList);
     closeListButton->hide();
 
 
@@ -87,8 +92,8 @@ SiteUsersList::SiteUsersList(PumpController *pumpController,
                                      "site-users",
                                      this);
     this->userList->hide();
-    connect(pController, SIGNAL(siteUserListReceived(QVariantList,int)),
-            this, SLOT(setListContents(QVariantList,int)));
+    connect(pController, &PumpController::siteUserListReceived,
+            this, &SiteUsersList::setListContents);
 
 
     this->middleLayout = new QHBoxLayout();
