@@ -64,7 +64,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
 #endif
 
     // Show date/time when latest stable version was released
-    demoObjectData.insert("published",      "2016-12-17T21:00:00Z");
+    demoObjectData.insert("published",      "2017-09-30T18:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -226,6 +226,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                                        QIcon(":/images/button-previous.png")),
                                       tr("Newest"),
                                       this);
+    firstPageButton->setFocusPolicy(Qt::ClickFocus);
     connect(firstPageButton, SIGNAL(clicked()),
             this, SLOT(goToFirstPage()));
 
@@ -239,6 +240,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                         this);
     currentPageButton->setSizePolicy(QSizePolicy::MinimumExpanding,
                                      QSizePolicy::Maximum);
+    currentPageButton->setFocusPolicy(Qt::ClickFocus);
     connect(currentPageButton, SIGNAL(clicked()),
             this, SLOT(showPageSelector()));
 
@@ -248,6 +250,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                                           QIcon(":/images/button-previous.png")),
                                          tr("Newer"),
                                          this);
+    previousPageButton->setFocusPolicy(Qt::ClickFocus);
     connect(previousPageButton, SIGNAL(clicked()),
             this, SLOT(goToPreviousPage()));
 
@@ -255,6 +258,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                                       QIcon(":/images/button-next.png")),
                                      tr("Older"),
                                      this);
+    nextPageButton->setFocusPolicy(Qt::ClickFocus);
     connect(nextPageButton, SIGNAL(clicked()),
             this, SLOT(goToNextPage()));
 
@@ -580,6 +584,12 @@ int TimeLine::getTotalPosts()
 }
 
 
+QString TimeLine::getCurrentPageAndTotalString() const
+{
+    return currentPageTotalString;
+}
+
+
 /*
  *  Update the button at the bottom of the page, indicating current "page"
  *
@@ -597,9 +607,9 @@ void TimeLine::updateCurrentPageNumber()
                                      .arg(currentPageString)
                                      .arg(totalPagesString));
 
-    this->currentPageButton->setToolTip(tr("Page %1 of %2.")
-                                        .arg(currentPageString)
-                                        .arg(totalPagesString)
+    this->currentPageTotalString = tr("Page %1 of %2.").arg(currentPageString)
+                                                       .arg(totalPagesString);
+    this->currentPageButton->setToolTip(this->currentPageTotalString
                                         + "<br>"
                                         + tr("Showing %1 posts per page.")
                                           .arg(this->postsPerPage)
@@ -1090,7 +1100,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
                               newPostCount, newHighlightedPostsCount,
                               newDirectPostsCount, newHLByFilterPostsCount,
                               newDeletedPostsCount, newFilteredPostsCount,
-                              pendingToReceiveNextTime);
+                              pendingToReceiveNextTime,
+                              ""); // Current page doesn't apply
 
         emit unreadPostsCountChanged(this->timelineType,
                                      unreadPostsCount,
@@ -1105,11 +1116,13 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
     }
     else
     {
+        this->updateCurrentPageNumber();
         emit timelineRendered(this->timelineType,
                               postListSize, -1, // Highlighted counts (direct and by filter)
                               -1, -1,           // are irrelevant in this case
                               newDeletedPostsCount, newFilteredPostsCount,
-                              -1);
+                              -1,               // And so is the "pending for next time"
+                              this->currentPageTotalString);
 
         emit unreadPostsCountChanged(this->timelineType,
                                      0, 0,
@@ -1565,3 +1578,4 @@ void TimeLine::updateAvatarFollowStates()
         post->syncAvatarFollowState();
     }
 }
+
