@@ -61,6 +61,7 @@ public:
     int getCurrentPage();
     int getTotalPages();
     int getTotalPosts();
+    QString getCurrentPageAndTotalString() const;
     void updateCurrentPageNumber();
     void syncPostsPerPage();
     void enablePaginationButtons();
@@ -92,7 +93,8 @@ signals:
                           int highlightedByFilterCount,
                           int deletedPostsCount,
                           int filteredPostsCount,
-                          int pendingForNextUpdate);
+                          int pendingForNextUpdate,
+                          QString currentPageAndTotal);
     void unreadPostsCountChanged(PumpController::requestTypes timelineType,
                                  int newPostCount,
                                  int highlightedCount,
@@ -179,6 +181,7 @@ private:
     int postsPerPage;
     int unreadPostsCount;
     int highlightedPostsCount;
+    QString currentPageTotalString;
 
     QAction *scrollUpAction;
     QAction *scrollDownAction;
