@@ -30,8 +30,8 @@ UserPosts::UserPosts(QString userId, QString userName,
 {
     this->pController = pumpController;
     this->globalObj = globalObject;
-    connect(globalObj, SIGNAL(programShuttingDown()),
-            this, SLOT(close()));
+    connect(globalObj, &GlobalObject::programShuttingDown,
+            this, &QWidget::close);
 
     this->setWindowFlags(Qt::Window);
     this->setWindowModality(Qt::NonModal);
@@ -57,8 +57,8 @@ UserPosts::UserPosts(QString userId, QString userName,
     this->scrollArea->setWidgetResizable(true);
     this->scrollArea->setFrameStyle(QFrame::Box | QFrame::Raised);
     this->scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
-    connect(timeline, SIGNAL(scrollTo(QAbstractSlider::SliderAction)),
-            this, SLOT(scrollTimelineTo(QAbstractSlider::SliderAction)));
+    connect(timeline, &TimeLine::scrollTo,
+            this, &UserPosts::scrollTimelineTo);
 
 
     this->infoLabel = new QLabel(tr("Loading..."), this);
@@ -66,19 +66,19 @@ UserPosts::UserPosts(QString userId, QString userName,
                                                          QIcon(":/images/button-close.png")),
                                         tr("&Close"),
                                         this);
-    connect(closeButton, SIGNAL(clicked()),
-            this, SLOT(close()));
+    connect(closeButton, &QAbstractButton::clicked,
+            this, &QWidget::close);
 
     // PumpController's connections
-    connect(pController, SIGNAL(userTimelineReceived(QVariantList,QString,QString,int,QString)),
-            this, SLOT(fillTimeLine(QVariantList,QString,QString,int,QString)));
-    connect(pController, SIGNAL(userTimelineFailed()),
-            this, SLOT(onTimelineFailed()));
-    connect(pController, SIGNAL(commentsReceived(QVariantList,QString)),
-            timeline, SLOT(setCommentsInPost(QVariantList,QString)));
+    connect(pController, &PumpController::userTimelineReceived,
+            this, &UserPosts::fillTimeLine);
+    connect(pController, &PumpController::userTimelineFailed,
+            this, &UserPosts::onTimelineFailed);
+    connect(pController, &PumpController::commentsReceived,
+            timeline, &TimeLine::setCommentsInPost);
 
-    connect(timeline, SIGNAL(timelineRendered(PumpController::requestTypes,int,int,int,int,int,int,int)),
-            this, SLOT(notifyTimelineUpdate()));
+    connect(timeline, &TimeLine::timelineRendered,
+            this, &UserPosts::notifyTimelineUpdate);
 
     // Initial load
     this->timeline->setCustomUrl(userOutbox);
